/********************************************************************************
** Form generated from reading UI file 'CameraControlsDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAMERACONTROLSDIALOG_H
#define UI_CAMERACONTROLSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CameraControlsDialog
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *camSettings;
    QGridLayout *gridLayout;
    QDoubleSpinBox *nearPlane;
    QDoubleSpinBox *farPlane;
    QLabel *label_3;
    QLabel *label_4;
    QSpacerItem *verticalSpacer;
    QGroupBox *navControls;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_5;
    QLabel *label_8;
    QLineEdit *backwardDisplay_2;
    QLineEdit *rightDisplay_2;
    QLineEdit *backwardDisplay;
    QLabel *label_2;
    QToolButton *backwardSet_2;
    QLineEdit *rightDisplay;
    QLineEdit *leftDisplay_2;
    QToolButton *downSet;
    QLabel *label_7;
    QLabel *label_9;
    QLineEdit *forwardDisplay_2;
    QLineEdit *leftDisplay;
    QToolButton *rightSet;
    QLineEdit *downDisplay_2;
    QLabel *label_11;
    QToolButton *leftSet;
    QToolButton *upSet_2;
    QLineEdit *upDisplay_2;
    QToolButton *leftSet_2;
    QToolButton *upSet;
    QToolButton *forwardSet_2;
    QToolButton *downSet_2;
    QLineEdit *downDisplay;
    QLabel *label_5;
    QLineEdit *forwardDisplay;
    QToolButton *forwardSet;
    QLabel *label_6;
    QLabel *label;
    QToolButton *backwardSet;
    QToolButton *rightSet_2;
    QLineEdit *upDisplay;
    QLabel *label_12;
    QComboBox *speedMod;
    QPushButton *resetAll;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CameraControlsDialog)
    {
        if (CameraControlsDialog->objectName().isEmpty())
            CameraControlsDialog->setObjectName(QString::fromUtf8("CameraControlsDialog"));
        CameraControlsDialog->resize(654, 288);
        gridLayout_2 = new QGridLayout(CameraControlsDialog);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        camSettings = new QGroupBox(CameraControlsDialog);
        camSettings->setObjectName(QString::fromUtf8("camSettings"));
        gridLayout = new QGridLayout(camSettings);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        nearPlane = new QDoubleSpinBox(camSettings);
        nearPlane->setObjectName(QString::fromUtf8("nearPlane"));
        nearPlane->setDecimals(4);
        nearPlane->setMinimum(0.000100000000000);
        nearPlane->setMaximum(10.000000000000000);
        nearPlane->setSingleStep(0.001000000000000);
        nearPlane->setValue(0.100000000000000);

        gridLayout->addWidget(nearPlane, 0, 1, 1, 1);

        farPlane = new QDoubleSpinBox(camSettings);
        farPlane->setObjectName(QString::fromUtf8("farPlane"));
        farPlane->setMinimum(20.000000000000000);
        farPlane->setMaximum(100000000.000000000000000);
        farPlane->setValue(100000.000000000000000);

        gridLayout->addWidget(farPlane, 1, 1, 1, 1);

        label_3 = new QLabel(camSettings);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        label_4 = new QLabel(camSettings);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);


        gridLayout_2->addWidget(camSettings, 0, 0, 1, 1);

        navControls = new QGroupBox(CameraControlsDialog);
        navControls->setObjectName(QString::fromUtf8("navControls"));
        verticalLayout = new QVBoxLayout(navControls);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        label_8 = new QLabel(navControls);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout_5->addWidget(label_8, 3, 0, 1, 1);

        backwardDisplay_2 = new QLineEdit(navControls);
        backwardDisplay_2->setObjectName(QString::fromUtf8("backwardDisplay_2"));
        backwardDisplay_2->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(backwardDisplay_2->sizePolicy().hasHeightForWidth());
        backwardDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(backwardDisplay_2, 2, 3, 1, 1);

        rightDisplay_2 = new QLineEdit(navControls);
        rightDisplay_2->setObjectName(QString::fromUtf8("rightDisplay_2"));
        rightDisplay_2->setEnabled(false);
        sizePolicy.setHeightForWidth(rightDisplay_2->sizePolicy().hasHeightForWidth());
        rightDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(rightDisplay_2, 4, 3, 1, 1);

        backwardDisplay = new QLineEdit(navControls);
        backwardDisplay->setObjectName(QString::fromUtf8("backwardDisplay"));
        backwardDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(backwardDisplay->sizePolicy().hasHeightForWidth());
        backwardDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(backwardDisplay, 2, 1, 1, 1);

        label_2 = new QLabel(navControls);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_5->addWidget(label_2, 6, 0, 1, 1);

        backwardSet_2 = new QToolButton(navControls);
        backwardSet_2->setObjectName(QString::fromUtf8("backwardSet_2"));

        gridLayout_5->addWidget(backwardSet_2, 2, 4, 1, 1);

        rightDisplay = new QLineEdit(navControls);
        rightDisplay->setObjectName(QString::fromUtf8("rightDisplay"));
        rightDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(rightDisplay->sizePolicy().hasHeightForWidth());
        rightDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(rightDisplay, 4, 1, 1, 1);

        leftDisplay_2 = new QLineEdit(navControls);
        leftDisplay_2->setObjectName(QString::fromUtf8("leftDisplay_2"));
        leftDisplay_2->setEnabled(false);
        sizePolicy.setHeightForWidth(leftDisplay_2->sizePolicy().hasHeightForWidth());
        leftDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(leftDisplay_2, 3, 3, 1, 1);

        downSet = new QToolButton(navControls);
        downSet->setObjectName(QString::fromUtf8("downSet"));

        gridLayout_5->addWidget(downSet, 6, 2, 1, 1);

        label_7 = new QLabel(navControls);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout_5->addWidget(label_7, 2, 0, 1, 1);

        label_9 = new QLabel(navControls);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout_5->addWidget(label_9, 0, 1, 1, 1);

        forwardDisplay_2 = new QLineEdit(navControls);
        forwardDisplay_2->setObjectName(QString::fromUtf8("forwardDisplay_2"));
        forwardDisplay_2->setEnabled(false);
        sizePolicy.setHeightForWidth(forwardDisplay_2->sizePolicy().hasHeightForWidth());
        forwardDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(forwardDisplay_2, 1, 3, 1, 1);

        leftDisplay = new QLineEdit(navControls);
        leftDisplay->setObjectName(QString::fromUtf8("leftDisplay"));
        leftDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(leftDisplay->sizePolicy().hasHeightForWidth());
        leftDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(leftDisplay, 3, 1, 1, 1);

        rightSet = new QToolButton(navControls);
        rightSet->setObjectName(QString::fromUtf8("rightSet"));

        gridLayout_5->addWidget(rightSet, 4, 2, 1, 1);

        downDisplay_2 = new QLineEdit(navControls);
        downDisplay_2->setObjectName(QString::fromUtf8("downDisplay_2"));
        downDisplay_2->setEnabled(false);
        sizePolicy.setHeightForWidth(downDisplay_2->sizePolicy().hasHeightForWidth());
        downDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(downDisplay_2, 6, 3, 1, 1);

        label_11 = new QLabel(navControls);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        gridLayout_5->addWidget(label_11, 0, 3, 1, 1);

        leftSet = new QToolButton(navControls);
        leftSet->setObjectName(QString::fromUtf8("leftSet"));

        gridLayout_5->addWidget(leftSet, 3, 2, 1, 1);

        upSet_2 = new QToolButton(navControls);
        upSet_2->setObjectName(QString::fromUtf8("upSet_2"));

        gridLayout_5->addWidget(upSet_2, 5, 4, 1, 1);

        upDisplay_2 = new QLineEdit(navControls);
        upDisplay_2->setObjectName(QString::fromUtf8("upDisplay_2"));
        upDisplay_2->setEnabled(false);
        sizePolicy.setHeightForWidth(upDisplay_2->sizePolicy().hasHeightForWidth());
        upDisplay_2->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(upDisplay_2, 5, 3, 1, 1);

        leftSet_2 = new QToolButton(navControls);
        leftSet_2->setObjectName(QString::fromUtf8("leftSet_2"));

        gridLayout_5->addWidget(leftSet_2, 3, 4, 1, 1);

        upSet = new QToolButton(navControls);
        upSet->setObjectName(QString::fromUtf8("upSet"));

        gridLayout_5->addWidget(upSet, 5, 2, 1, 1);

        forwardSet_2 = new QToolButton(navControls);
        forwardSet_2->setObjectName(QString::fromUtf8("forwardSet_2"));

        gridLayout_5->addWidget(forwardSet_2, 1, 4, 1, 1);

        downSet_2 = new QToolButton(navControls);
        downSet_2->setObjectName(QString::fromUtf8("downSet_2"));

        gridLayout_5->addWidget(downSet_2, 6, 4, 1, 1);

        downDisplay = new QLineEdit(navControls);
        downDisplay->setObjectName(QString::fromUtf8("downDisplay"));
        downDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(downDisplay->sizePolicy().hasHeightForWidth());
        downDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(downDisplay, 6, 1, 1, 1);

        label_5 = new QLabel(navControls);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout_5->addWidget(label_5, 4, 0, 1, 1);

        forwardDisplay = new QLineEdit(navControls);
        forwardDisplay->setObjectName(QString::fromUtf8("forwardDisplay"));
        forwardDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(forwardDisplay->sizePolicy().hasHeightForWidth());
        forwardDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(forwardDisplay, 1, 1, 1, 1);

        forwardSet = new QToolButton(navControls);
        forwardSet->setObjectName(QString::fromUtf8("forwardSet"));

        gridLayout_5->addWidget(forwardSet, 1, 2, 1, 1);

        label_6 = new QLabel(navControls);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout_5->addWidget(label_6, 1, 0, 1, 1);

        label = new QLabel(navControls);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_5->addWidget(label, 5, 0, 1, 1);

        backwardSet = new QToolButton(navControls);
        backwardSet->setObjectName(QString::fromUtf8("backwardSet"));

        gridLayout_5->addWidget(backwardSet, 2, 2, 1, 1);

        rightSet_2 = new QToolButton(navControls);
        rightSet_2->setObjectName(QString::fromUtf8("rightSet_2"));

        gridLayout_5->addWidget(rightSet_2, 4, 4, 1, 1);

        upDisplay = new QLineEdit(navControls);
        upDisplay->setObjectName(QString::fromUtf8("upDisplay"));
        upDisplay->setEnabled(false);
        sizePolicy.setHeightForWidth(upDisplay->sizePolicy().hasHeightForWidth());
        upDisplay->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(upDisplay, 5, 1, 1, 1);

        label_12 = new QLabel(navControls);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        gridLayout_5->addWidget(label_12, 7, 0, 1, 1);

        speedMod = new QComboBox(navControls);
        speedMod->addItem(QString());
        speedMod->addItem(QString());
        speedMod->addItem(QString());
        speedMod->addItem(QString());
        speedMod->setObjectName(QString::fromUtf8("speedMod"));

        gridLayout_5->addWidget(speedMod, 7, 1, 1, 1);

        resetAll = new QPushButton(navControls);
        resetAll->setObjectName(QString::fromUtf8("resetAll"));

        gridLayout_5->addWidget(resetAll, 7, 3, 1, 2);


        verticalLayout->addLayout(gridLayout_5);


        gridLayout_2->addWidget(navControls, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(CameraControlsDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(true);

        gridLayout_2->addWidget(buttonBox, 1, 0, 1, 2);

        QWidget::setTabOrder(nearPlane, farPlane);
        QWidget::setTabOrder(farPlane, forwardSet);
        QWidget::setTabOrder(forwardSet, backwardSet);
        QWidget::setTabOrder(backwardSet, leftSet);
        QWidget::setTabOrder(leftSet, rightSet);
        QWidget::setTabOrder(rightSet, upSet);
        QWidget::setTabOrder(upSet, downSet);
        QWidget::setTabOrder(downSet, forwardSet_2);
        QWidget::setTabOrder(forwardSet_2, backwardSet_2);
        QWidget::setTabOrder(backwardSet_2, leftSet_2);
        QWidget::setTabOrder(leftSet_2, rightSet_2);
        QWidget::setTabOrder(rightSet_2, upSet_2);
        QWidget::setTabOrder(upSet_2, downSet_2);
        QWidget::setTabOrder(downSet_2, speedMod);
        QWidget::setTabOrder(speedMod, resetAll);
        QWidget::setTabOrder(resetAll, forwardDisplay);
        QWidget::setTabOrder(forwardDisplay, backwardDisplay);
        QWidget::setTabOrder(backwardDisplay, leftDisplay);
        QWidget::setTabOrder(leftDisplay, rightDisplay);
        QWidget::setTabOrder(rightDisplay, upDisplay);
        QWidget::setTabOrder(upDisplay, downDisplay);
        QWidget::setTabOrder(downDisplay, forwardDisplay_2);
        QWidget::setTabOrder(forwardDisplay_2, backwardDisplay_2);
        QWidget::setTabOrder(backwardDisplay_2, leftDisplay_2);
        QWidget::setTabOrder(leftDisplay_2, rightDisplay_2);
        QWidget::setTabOrder(rightDisplay_2, upDisplay_2);
        QWidget::setTabOrder(upDisplay_2, downDisplay_2);

        retranslateUi(CameraControlsDialog);

        QMetaObject::connectSlotsByName(CameraControlsDialog);
    } // setupUi

    void retranslateUi(QDialog *CameraControlsDialog)
    {
        CameraControlsDialog->setWindowTitle(QCoreApplication::translate("CameraControlsDialog", "Camera Settings & Controls", nullptr));
        camSettings->setTitle(QCoreApplication::translate("CameraControlsDialog", "Camera Settings", nullptr));
        label_3->setText(QCoreApplication::translate("CameraControlsDialog", "Near plane:", nullptr));
        label_4->setText(QCoreApplication::translate("CameraControlsDialog", "Far plane:", nullptr));
        navControls->setTitle(QCoreApplication::translate("CameraControlsDialog", "Flycam Controls", nullptr));
        label_8->setText(QCoreApplication::translate("CameraControlsDialog", "Left:", nullptr));
        label_2->setText(QCoreApplication::translate("CameraControlsDialog", "Vertically Down:", nullptr));
        backwardSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        downSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        label_7->setText(QCoreApplication::translate("CameraControlsDialog", "Backward:", nullptr));
        label_9->setText(QCoreApplication::translate("CameraControlsDialog", "Primary", nullptr));
        rightSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        label_11->setText(QCoreApplication::translate("CameraControlsDialog", "Secondary", nullptr));
        leftSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        upSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        leftSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        upSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        forwardSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        downSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        label_5->setText(QCoreApplication::translate("CameraControlsDialog", "Right:", nullptr));
        forwardSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        label_6->setText(QCoreApplication::translate("CameraControlsDialog", "Forward:", nullptr));
        label->setText(QCoreApplication::translate("CameraControlsDialog", "Vertically Up:", nullptr));
        backwardSet->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        rightSet_2->setText(QCoreApplication::translate("CameraControlsDialog", "Set", nullptr));
        label_12->setText(QCoreApplication::translate("CameraControlsDialog", "Faster Movement:", nullptr));
        speedMod->setItemText(0, QCoreApplication::translate("CameraControlsDialog", "Shift", nullptr));
        speedMod->setItemText(1, QCoreApplication::translate("CameraControlsDialog", "Alt", nullptr));
        speedMod->setItemText(2, QCoreApplication::translate("CameraControlsDialog", "Control", nullptr));
        speedMod->setItemText(3, QCoreApplication::translate("CameraControlsDialog", "Disabled", nullptr));

        resetAll->setText(QCoreApplication::translate("CameraControlsDialog", "Reset All to Default", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CameraControlsDialog: public Ui_CameraControlsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CAMERACONTROLSDIALOG_H
