/****************************************************************************
** Meta object code from reading C++ file 'EnvironmentEditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/EnvironmentEditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'EnvironmentEditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EnvironmentEditor_t {
    QByteArrayData data[14];
    char stringdata0[217];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EnvironmentEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EnvironmentEditor_t qt_meta_stringdata_EnvironmentEditor = {
    {
QT_MOC_LITERAL(0, 0, 17), // "EnvironmentEditor"
QT_MOC_LITERAL(1, 18, 19), // "on_name_textChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 4), // "text"
QT_MOC_LITERAL(4, 44, 20), // "on_addUpdate_clicked"
QT_MOC_LITERAL(5, 65, 23), // "on_deleteButton_clicked"
QT_MOC_LITERAL(6, 89, 21), // "on_variables_keyPress"
QT_MOC_LITERAL(7, 111, 10), // "QKeyEvent*"
QT_MOC_LITERAL(8, 122, 5), // "event"
QT_MOC_LITERAL(9, 128, 31), // "on_variables_currentItemChanged"
QT_MOC_LITERAL(10, 160, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(11, 178, 7), // "current"
QT_MOC_LITERAL(12, 186, 8), // "previous"
QT_MOC_LITERAL(13, 195, 21) // "on_buttonBox_accepted"

    },
    "EnvironmentEditor\0on_name_textChanged\0"
    "\0text\0on_addUpdate_clicked\0"
    "on_deleteButton_clicked\0on_variables_keyPress\0"
    "QKeyEvent*\0event\0on_variables_currentItemChanged\0"
    "RDTreeWidgetItem*\0current\0previous\0"
    "on_buttonBox_accepted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EnvironmentEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x0a /* Public */,
       4,    0,   47,    2, 0x0a /* Public */,
       5,    0,   48,    2, 0x0a /* Public */,
       6,    1,   49,    2, 0x0a /* Public */,
       9,    2,   52,    2, 0x0a /* Public */,
      13,    0,   57,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 10,   11,   12,
    QMetaType::Void,

       0        // eod
};

void EnvironmentEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EnvironmentEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_name_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->on_addUpdate_clicked(); break;
        case 2: _t->on_deleteButton_clicked(); break;
        case 3: _t->on_variables_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 4: _t->on_variables_currentItemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[2]))); break;
        case 5: _t->on_buttonBox_accepted(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject EnvironmentEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_EnvironmentEditor.data,
    qt_meta_data_EnvironmentEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EnvironmentEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EnvironmentEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EnvironmentEditor.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int EnvironmentEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
