/****************************************************************************
** Meta object code from reading C++ file 'ComputeDebugSelector.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/ComputeDebugSelector.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ComputeDebugSelector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ComputeDebugSelector_t {
    QByteArrayData data[18];
    char stringdata0[338];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ComputeDebugSelector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ComputeDebugSelector_t qt_meta_stringdata_ComputeDebugSelector = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ComputeDebugSelector"
QT_MOC_LITERAL(1, 21, 10), // "beginDebug"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 25), // "rdcfixedarray<uint32_t,3>"
QT_MOC_LITERAL(4, 59, 5), // "group"
QT_MOC_LITERAL(5, 65, 6), // "thread"
QT_MOC_LITERAL(6, 72, 22), // "on_groupX_valueChanged"
QT_MOC_LITERAL(7, 95, 1), // "i"
QT_MOC_LITERAL(8, 97, 22), // "on_groupY_valueChanged"
QT_MOC_LITERAL(9, 120, 22), // "on_groupZ_valueChanged"
QT_MOC_LITERAL(10, 143, 23), // "on_threadX_valueChanged"
QT_MOC_LITERAL(11, 167, 23), // "on_threadY_valueChanged"
QT_MOC_LITERAL(12, 191, 23), // "on_threadZ_valueChanged"
QT_MOC_LITERAL(13, 215, 25), // "on_dispatchX_valueChanged"
QT_MOC_LITERAL(14, 241, 25), // "on_dispatchY_valueChanged"
QT_MOC_LITERAL(15, 267, 25), // "on_dispatchZ_valueChanged"
QT_MOC_LITERAL(16, 293, 21), // "on_beginDebug_clicked"
QT_MOC_LITERAL(17, 315, 22) // "on_cancelDebug_clicked"

    },
    "ComputeDebugSelector\0beginDebug\0\0"
    "rdcfixedarray<uint32_t,3>\0group\0thread\0"
    "on_groupX_valueChanged\0i\0"
    "on_groupY_valueChanged\0on_groupZ_valueChanged\0"
    "on_threadX_valueChanged\0on_threadY_valueChanged\0"
    "on_threadZ_valueChanged\0"
    "on_dispatchX_valueChanged\0"
    "on_dispatchY_valueChanged\0"
    "on_dispatchZ_valueChanged\0"
    "on_beginDebug_clicked\0on_cancelDebug_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ComputeDebugSelector[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   79,    2, 0x08 /* Private */,
       8,    1,   82,    2, 0x08 /* Private */,
       9,    1,   85,    2, 0x08 /* Private */,
      10,    1,   88,    2, 0x08 /* Private */,
      11,    1,   91,    2, 0x08 /* Private */,
      12,    1,   94,    2, 0x08 /* Private */,
      13,    1,   97,    2, 0x08 /* Private */,
      14,    1,  100,    2, 0x08 /* Private */,
      15,    1,  103,    2, 0x08 /* Private */,
      16,    0,  106,    2, 0x08 /* Private */,
      17,    0,  107,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ComputeDebugSelector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ComputeDebugSelector *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->beginDebug((*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[1])),(*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[2]))); break;
        case 1: _t->on_groupX_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->on_groupY_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_groupZ_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_threadX_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->on_threadY_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->on_threadZ_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_dispatchX_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_dispatchY_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_dispatchZ_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_beginDebug_clicked(); break;
        case 11: _t->on_cancelDebug_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ComputeDebugSelector::*)(const rdcfixedarray<uint32_t,3> & , const rdcfixedarray<uint32_t,3> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ComputeDebugSelector::beginDebug)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ComputeDebugSelector::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_ComputeDebugSelector.data,
    qt_meta_data_ComputeDebugSelector,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ComputeDebugSelector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComputeDebugSelector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ComputeDebugSelector.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ComputeDebugSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ComputeDebugSelector::beginDebug(const rdcfixedarray<uint32_t,3> & _t1, const rdcfixedarray<uint32_t,3> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
