/****************************************************************************
** Meta object code from reading C++ file 'EventBrowser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/EventBrowser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'EventBrowser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ParseErrorTipLabel_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ParseErrorTipLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ParseErrorTipLabel_t qt_meta_stringdata_ParseErrorTipLabel = {
    {
QT_MOC_LITERAL(0, 0, 18) // "ParseErrorTipLabel"

    },
    "ParseErrorTipLabel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ParseErrorTipLabel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ParseErrorTipLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ParseErrorTipLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_meta_stringdata_ParseErrorTipLabel.data,
    qt_meta_data_ParseErrorTipLabel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ParseErrorTipLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ParseErrorTipLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ParseErrorTipLabel.stringdata0))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int ParseErrorTipLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_EventBrowser_t {
    QByteArrayData data[48];
    char stringdata0[855];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventBrowser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventBrowser_t qt_meta_stringdata_EventBrowser = {
    {
QT_MOC_LITERAL(0, 0, 12), // "EventBrowser"
QT_MOC_LITERAL(1, 13, 15), // "on_find_toggled"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 7), // "checked"
QT_MOC_LITERAL(4, 38, 22), // "on_timeActions_clicked"
QT_MOC_LITERAL(5, 61, 19), // "on_bookmark_clicked"
QT_MOC_LITERAL(6, 81, 11), // "on_HideFind"
QT_MOC_LITERAL(7, 93, 26), // "on_findEvent_returnPressed"
QT_MOC_LITERAL(8, 120, 21), // "on_findEvent_keyPress"
QT_MOC_LITERAL(9, 142, 10), // "QKeyEvent*"
QT_MOC_LITERAL(10, 153, 5), // "event"
QT_MOC_LITERAL(11, 159, 23), // "on_findEvent_textEdited"
QT_MOC_LITERAL(12, 183, 4), // "arg1"
QT_MOC_LITERAL(13, 188, 28), // "on_filterExpression_keyPress"
QT_MOC_LITERAL(14, 217, 31), // "on_filterExpression_textChanged"
QT_MOC_LITERAL(15, 249, 30), // "on_filterExpression_mouseMoved"
QT_MOC_LITERAL(16, 280, 12), // "QMouseEvent*"
QT_MOC_LITERAL(17, 293, 30), // "on_filterExpression_hoverEnter"
QT_MOC_LITERAL(18, 324, 30), // "on_filterExpression_hoverLeave"
QT_MOC_LITERAL(19, 355, 19), // "on_findNext_clicked"
QT_MOC_LITERAL(20, 375, 19), // "on_findPrev_clicked"
QT_MOC_LITERAL(21, 395, 19), // "on_stepNext_clicked"
QT_MOC_LITERAL(22, 415, 19), // "on_stepPrev_clicked"
QT_MOC_LITERAL(23, 435, 24), // "on_exportActions_clicked"
QT_MOC_LITERAL(24, 460, 20), // "on_colSelect_clicked"
QT_MOC_LITERAL(25, 481, 21), // "findHighlight_timeout"
QT_MOC_LITERAL(26, 503, 30), // "explanation_currentItemChanged"
QT_MOC_LITERAL(27, 534, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(28, 552, 7), // "current"
QT_MOC_LITERAL(29, 560, 4), // "prev"
QT_MOC_LITERAL(30, 565, 20), // "settings_filterApply"
QT_MOC_LITERAL(31, 586, 22), // "filterSettings_clicked"
QT_MOC_LITERAL(32, 609, 31), // "filter_forceCompletion_keyPress"
QT_MOC_LITERAL(33, 641, 1), // "e"
QT_MOC_LITERAL(34, 643, 20), // "savedFilter_keyPress"
QT_MOC_LITERAL(35, 664, 22), // "filter_CompletionBegin"
QT_MOC_LITERAL(36, 687, 6), // "prefix"
QT_MOC_LITERAL(37, 694, 12), // "filter_apply"
QT_MOC_LITERAL(38, 707, 15), // "events_keyPress"
QT_MOC_LITERAL(39, 723, 18), // "events_contextMenu"
QT_MOC_LITERAL(40, 742, 3), // "pos"
QT_MOC_LITERAL(41, 746, 21), // "events_currentChanged"
QT_MOC_LITERAL(42, 768, 11), // "QModelIndex"
QT_MOC_LITERAL(43, 780, 8), // "previous"
QT_MOC_LITERAL(44, 789, 20), // "locationEdit_clicked"
QT_MOC_LITERAL(45, 810, 14), // "location_leave"
QT_MOC_LITERAL(46, 825, 17), // "location_keyPress"
QT_MOC_LITERAL(47, 843, 11) // "persistData"

    },
    "EventBrowser\0on_find_toggled\0\0checked\0"
    "on_timeActions_clicked\0on_bookmark_clicked\0"
    "on_HideFind\0on_findEvent_returnPressed\0"
    "on_findEvent_keyPress\0QKeyEvent*\0event\0"
    "on_findEvent_textEdited\0arg1\0"
    "on_filterExpression_keyPress\0"
    "on_filterExpression_textChanged\0"
    "on_filterExpression_mouseMoved\0"
    "QMouseEvent*\0on_filterExpression_hoverEnter\0"
    "on_filterExpression_hoverLeave\0"
    "on_findNext_clicked\0on_findPrev_clicked\0"
    "on_stepNext_clicked\0on_stepPrev_clicked\0"
    "on_exportActions_clicked\0on_colSelect_clicked\0"
    "findHighlight_timeout\0"
    "explanation_currentItemChanged\0"
    "RDTreeWidgetItem*\0current\0prev\0"
    "settings_filterApply\0filterSettings_clicked\0"
    "filter_forceCompletion_keyPress\0e\0"
    "savedFilter_keyPress\0filter_CompletionBegin\0"
    "prefix\0filter_apply\0events_keyPress\0"
    "events_contextMenu\0pos\0events_currentChanged\0"
    "QModelIndex\0previous\0locationEdit_clicked\0"
    "location_leave\0location_keyPress\0"
    "persistData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventBrowser[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       1,  236, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  174,    2, 0x08 /* Private */,
       4,    0,  177,    2, 0x08 /* Private */,
       5,    0,  178,    2, 0x08 /* Private */,
       6,    0,  179,    2, 0x08 /* Private */,
       7,    0,  180,    2, 0x08 /* Private */,
       8,    1,  181,    2, 0x08 /* Private */,
      11,    1,  184,    2, 0x08 /* Private */,
      13,    1,  187,    2, 0x08 /* Private */,
      14,    0,  190,    2, 0x08 /* Private */,
      15,    1,  191,    2, 0x08 /* Private */,
      17,    0,  194,    2, 0x08 /* Private */,
      18,    0,  195,    2, 0x08 /* Private */,
      19,    0,  196,    2, 0x08 /* Private */,
      20,    0,  197,    2, 0x08 /* Private */,
      21,    0,  198,    2, 0x08 /* Private */,
      22,    0,  199,    2, 0x08 /* Private */,
      23,    0,  200,    2, 0x08 /* Private */,
      24,    0,  201,    2, 0x08 /* Private */,
      25,    0,  202,    2, 0x08 /* Private */,
      26,    2,  203,    2, 0x08 /* Private */,
      30,    0,  208,    2, 0x08 /* Private */,
      31,    0,  209,    2, 0x08 /* Private */,
      32,    1,  210,    2, 0x08 /* Private */,
      34,    1,  213,    2, 0x08 /* Private */,
      35,    1,  216,    2, 0x08 /* Private */,
      37,    0,  219,    2, 0x08 /* Private */,
      38,    1,  220,    2, 0x08 /* Private */,
      39,    1,  223,    2, 0x08 /* Private */,
      41,    2,  226,    2, 0x08 /* Private */,
      44,    0,  231,    2, 0x08 /* Private */,
      45,    0,  232,    2, 0x08 /* Private */,
      46,    1,  233,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27, 0x80000000 | 27,   28,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   33,
    QMetaType::Void, 0x80000000 | 9,   33,
    QMetaType::Void, QMetaType::QString,   36,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QPoint,   40,
    QMetaType::Void, 0x80000000 | 42, 0x80000000 | 42,   28,   43,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   33,

 // properties: name, type, flags
      47, QMetaType::QVariant, 0x00090103,

       0        // eod
};

void EventBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EventBrowser *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_find_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->on_timeActions_clicked(); break;
        case 2: _t->on_bookmark_clicked(); break;
        case 3: _t->on_HideFind(); break;
        case 4: _t->on_findEvent_returnPressed(); break;
        case 5: _t->on_findEvent_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 6: _t->on_findEvent_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->on_filterExpression_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 8: _t->on_filterExpression_textChanged(); break;
        case 9: _t->on_filterExpression_mouseMoved((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 10: _t->on_filterExpression_hoverEnter(); break;
        case 11: _t->on_filterExpression_hoverLeave(); break;
        case 12: _t->on_findNext_clicked(); break;
        case 13: _t->on_findPrev_clicked(); break;
        case 14: _t->on_stepNext_clicked(); break;
        case 15: _t->on_stepPrev_clicked(); break;
        case 16: _t->on_exportActions_clicked(); break;
        case 17: _t->on_colSelect_clicked(); break;
        case 18: _t->findHighlight_timeout(); break;
        case 19: _t->explanation_currentItemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[2]))); break;
        case 20: _t->settings_filterApply(); break;
        case 21: _t->filterSettings_clicked(); break;
        case 22: _t->filter_forceCompletion_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 23: _t->savedFilter_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 24: _t->filter_CompletionBegin((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 25: _t->filter_apply(); break;
        case 26: _t->events_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 27: _t->events_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 28: _t->events_currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 29: _t->locationEdit_clicked(); break;
        case 30: _t->location_leave(); break;
        case 31: _t->location_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<EventBrowser *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->persistData(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<EventBrowser *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPersistData(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject EventBrowser::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_EventBrowser.data,
    qt_meta_data_EventBrowser,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EventBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventBrowser.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IEventBrowser"))
        return static_cast< IEventBrowser*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 32;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
