/****************************************************************************
** Meta object code from reading C++ file 'VirtualFileDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/VirtualFileDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'VirtualFileDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_VirtualFileDialog_t {
    QByteArrayData data[24];
    char stringdata0[401];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VirtualFileDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VirtualFileDialog_t qt_meta_stringdata_VirtualFileDialog = {
    {
QT_MOC_LITERAL(0, 0, 17), // "VirtualFileDialog"
QT_MOC_LITERAL(1, 18, 18), // "on_dirList_clicked"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 50, 5), // "index"
QT_MOC_LITERAL(5, 56, 25), // "on_fileList_doubleClicked"
QT_MOC_LITERAL(6, 82, 19), // "on_fileList_clicked"
QT_MOC_LITERAL(7, 102, 20), // "on_fileList_keyPress"
QT_MOC_LITERAL(8, 123, 10), // "QKeyEvent*"
QT_MOC_LITERAL(9, 134, 1), // "e"
QT_MOC_LITERAL(10, 136, 21), // "on_showHidden_toggled"
QT_MOC_LITERAL(11, 158, 7), // "checked"
QT_MOC_LITERAL(12, 166, 20), // "on_filename_keyPress"
QT_MOC_LITERAL(13, 187, 29), // "on_filter_currentIndexChanged"
QT_MOC_LITERAL(14, 217, 20), // "on_location_keyPress"
QT_MOC_LITERAL(15, 238, 21), // "on_buttonBox_accepted"
QT_MOC_LITERAL(16, 260, 15), // "on_back_clicked"
QT_MOC_LITERAL(17, 276, 18), // "on_forward_clicked"
QT_MOC_LITERAL(18, 295, 19), // "on_upFolder_clicked"
QT_MOC_LITERAL(19, 315, 24), // "dirList_selectionChanged"
QT_MOC_LITERAL(20, 340, 14), // "QItemSelection"
QT_MOC_LITERAL(21, 355, 8), // "selected"
QT_MOC_LITERAL(22, 364, 10), // "deselected"
QT_MOC_LITERAL(23, 375, 25) // "fileList_selectionChanged"

    },
    "VirtualFileDialog\0on_dirList_clicked\0"
    "\0QModelIndex\0index\0on_fileList_doubleClicked\0"
    "on_fileList_clicked\0on_fileList_keyPress\0"
    "QKeyEvent*\0e\0on_showHidden_toggled\0"
    "checked\0on_filename_keyPress\0"
    "on_filter_currentIndexChanged\0"
    "on_location_keyPress\0on_buttonBox_accepted\0"
    "on_back_clicked\0on_forward_clicked\0"
    "on_upFolder_clicked\0dirList_selectionChanged\0"
    "QItemSelection\0selected\0deselected\0"
    "fileList_selectionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VirtualFileDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x08 /* Private */,
       5,    1,   87,    2, 0x08 /* Private */,
       6,    1,   90,    2, 0x08 /* Private */,
       7,    1,   93,    2, 0x08 /* Private */,
      10,    1,   96,    2, 0x08 /* Private */,
      12,    1,   99,    2, 0x08 /* Private */,
      13,    1,  102,    2, 0x08 /* Private */,
      14,    1,  105,    2, 0x08 /* Private */,
      15,    0,  108,    2, 0x08 /* Private */,
      16,    0,  109,    2, 0x08 /* Private */,
      17,    0,  110,    2, 0x08 /* Private */,
      18,    0,  111,    2, 0x08 /* Private */,
      19,    2,  112,    2, 0x08 /* Private */,
      23,    2,  117,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20, 0x80000000 | 20,   21,   22,
    QMetaType::Void, 0x80000000 | 20, 0x80000000 | 20,   21,   22,

       0        // eod
};

void VirtualFileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VirtualFileDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_dirList_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->on_fileList_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->on_fileList_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->on_fileList_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 4: _t->on_showHidden_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->on_filename_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 6: _t->on_filter_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_location_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 8: _t->on_buttonBox_accepted(); break;
        case 9: _t->on_back_clicked(); break;
        case 10: _t->on_forward_clicked(); break;
        case 11: _t->on_upFolder_clicked(); break;
        case 12: _t->dirList_selectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 13: _t->fileList_selectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject VirtualFileDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_VirtualFileDialog.data,
    qt_meta_data_VirtualFileDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *VirtualFileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VirtualFileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_VirtualFileDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int VirtualFileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
