/****************************************************************************
** Meta object code from reading C++ file 'PythonShell.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/PythonShell.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PythonShell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PythonShell_t {
    QByteArrayData data[27];
    char stringdata0[334];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PythonShell_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PythonShell_t qt_meta_stringdata_PythonShell = {
    {
QT_MOC_LITERAL(0, 0, 11), // "PythonShell"
QT_MOC_LITERAL(1, 12, 18), // "on_execute_clicked"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 16), // "on_clear_clicked"
QT_MOC_LITERAL(4, 49, 20), // "on_newScript_clicked"
QT_MOC_LITERAL(5, 70, 21), // "on_openScript_clicked"
QT_MOC_LITERAL(6, 92, 21), // "on_saveScript_clicked"
QT_MOC_LITERAL(7, 114, 20), // "on_runScript_clicked"
QT_MOC_LITERAL(8, 135, 19), // "on_abortRun_clicked"
QT_MOC_LITERAL(9, 155, 20), // "interactive_keypress"
QT_MOC_LITERAL(10, 176, 10), // "QKeyEvent*"
QT_MOC_LITERAL(11, 187, 1), // "e"
QT_MOC_LITERAL(12, 189, 19), // "helpSearch_keypress"
QT_MOC_LITERAL(13, 209, 9), // "traceLine"
QT_MOC_LITERAL(14, 219, 4), // "file"
QT_MOC_LITERAL(15, 224, 4), // "line"
QT_MOC_LITERAL(16, 229, 9), // "exception"
QT_MOC_LITERAL(17, 239, 4), // "type"
QT_MOC_LITERAL(18, 244, 5), // "value"
QT_MOC_LITERAL(19, 250, 9), // "finalLine"
QT_MOC_LITERAL(20, 260, 14), // "QList<QString>"
QT_MOC_LITERAL(21, 275, 6), // "frames"
QT_MOC_LITERAL(22, 282, 10), // "textOutput"
QT_MOC_LITERAL(23, 293, 10), // "isStdError"
QT_MOC_LITERAL(24, 304, 6), // "output"
QT_MOC_LITERAL(25, 311, 18), // "editor_contextMenu"
QT_MOC_LITERAL(26, 330, 3) // "pos"

    },
    "PythonShell\0on_execute_clicked\0\0"
    "on_clear_clicked\0on_newScript_clicked\0"
    "on_openScript_clicked\0on_saveScript_clicked\0"
    "on_runScript_clicked\0on_abortRun_clicked\0"
    "interactive_keypress\0QKeyEvent*\0e\0"
    "helpSearch_keypress\0traceLine\0file\0"
    "line\0exception\0type\0value\0finalLine\0"
    "QList<QString>\0frames\0textOutput\0"
    "isStdError\0output\0editor_contextMenu\0"
    "pos"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PythonShell[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x08 /* Private */,
       3,    0,   80,    2, 0x08 /* Private */,
       4,    0,   81,    2, 0x08 /* Private */,
       5,    0,   82,    2, 0x08 /* Private */,
       6,    0,   83,    2, 0x08 /* Private */,
       7,    0,   84,    2, 0x08 /* Private */,
       8,    0,   85,    2, 0x08 /* Private */,
       9,    1,   86,    2, 0x08 /* Private */,
      12,    1,   89,    2, 0x08 /* Private */,
      13,    2,   92,    2, 0x08 /* Private */,
      16,    4,   97,    2, 0x08 /* Private */,
      22,    2,  106,    2, 0x08 /* Private */,
      25,    1,  111,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   14,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int, 0x80000000 | 20,   17,   18,   19,   21,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString,   23,   24,
    QMetaType::Void, QMetaType::QPoint,   26,

       0        // eod
};

void PythonShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PythonShell *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_execute_clicked(); break;
        case 1: _t->on_clear_clicked(); break;
        case 2: _t->on_newScript_clicked(); break;
        case 3: _t->on_openScript_clicked(); break;
        case 4: _t->on_saveScript_clicked(); break;
        case 5: _t->on_runScript_clicked(); break;
        case 6: _t->on_abortRun_clicked(); break;
        case 7: _t->interactive_keypress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 8: _t->helpSearch_keypress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 9: _t->traceLine((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->exception((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< QList<QString>(*)>(_a[4]))); break;
        case 11: _t->textOutput((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->editor_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PythonShell::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_PythonShell.data,
    qt_meta_data_PythonShell,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PythonShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PythonShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PythonShell.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IPythonShell"))
        return static_cast< IPythonShell*>(this);
    return QFrame::qt_metacast(_clname);
}

int PythonShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
