/********************************************************************************
** Form generated from reading UI file 'ProjectionGuessDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTIONGUESSDIALOG_H
#define UI_PROJECTIONGUESSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ProjectionGuessDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QFrame *line;
    QGridLayout *gridLayout_5;
    QLineEdit *aspectRatio;
    QLineEdit *nearPlane;
    QDoubleSpinBox *fov;
    QLabel *label_6;
    QLabel *label_4;
    QLineEdit *farPlane;
    QLabel *label_2;
    QLabel *label_5;
    QLabel *label_3;
    QComboBox *matrixType;
    QCheckBox *infiniteFar;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ProjectionGuessDialog)
    {
        if (ProjectionGuessDialog->objectName().isEmpty())
            ProjectionGuessDialog->setObjectName(QString::fromUtf8("ProjectionGuessDialog"));
        ProjectionGuessDialog->resize(296, 356);
        verticalLayout = new QVBoxLayout(ProjectionGuessDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(10, 10, 10, 10);
        label = new QLabel(ProjectionGuessDialog);
        label->setObjectName(QString::fromUtf8("label"));
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        line = new QFrame(ProjectionGuessDialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        gridLayout_5->setContentsMargins(-1, -1, -1, 10);
        aspectRatio = new QLineEdit(ProjectionGuessDialog);
        aspectRatio->setObjectName(QString::fromUtf8("aspectRatio"));
        aspectRatio->setClearButtonEnabled(true);

        gridLayout_5->addWidget(aspectRatio, 2, 1, 1, 1);

        nearPlane = new QLineEdit(ProjectionGuessDialog);
        nearPlane->setObjectName(QString::fromUtf8("nearPlane"));
        nearPlane->setClearButtonEnabled(true);

        gridLayout_5->addWidget(nearPlane, 3, 1, 1, 1);

        fov = new QDoubleSpinBox(ProjectionGuessDialog);
        fov->setObjectName(QString::fromUtf8("fov"));
        fov->setDecimals(1);
        fov->setMinimum(1.000000000000000);
        fov->setMaximum(179.000000000000000);
        fov->setValue(90.000000000000000);

        gridLayout_5->addWidget(fov, 1, 1, 1, 1);

        label_6 = new QLabel(ProjectionGuessDialog);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout_5->addWidget(label_6, 4, 0, 1, 1);

        label_4 = new QLabel(ProjectionGuessDialog);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout_5->addWidget(label_4, 2, 0, 1, 1);

        farPlane = new QLineEdit(ProjectionGuessDialog);
        farPlane->setObjectName(QString::fromUtf8("farPlane"));
        farPlane->setClearButtonEnabled(true);

        gridLayout_5->addWidget(farPlane, 4, 1, 1, 1);

        label_2 = new QLabel(ProjectionGuessDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_5->addWidget(label_2, 0, 0, 1, 1);

        label_5 = new QLabel(ProjectionGuessDialog);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout_5->addWidget(label_5, 3, 0, 1, 1);

        label_3 = new QLabel(ProjectionGuessDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout_5->addWidget(label_3, 1, 0, 1, 1);

        matrixType = new QComboBox(ProjectionGuessDialog);
        matrixType->addItem(QString());
        matrixType->addItem(QString());
        matrixType->setObjectName(QString::fromUtf8("matrixType"));

        gridLayout_5->addWidget(matrixType, 0, 1, 1, 1);

        infiniteFar = new QCheckBox(ProjectionGuessDialog);
        infiniteFar->setObjectName(QString::fromUtf8("infiniteFar"));

        gridLayout_5->addWidget(infiniteFar, 5, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_5);

        buttonBox = new QDialogButtonBox(ProjectionGuessDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(true);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(matrixType, fov);
        QWidget::setTabOrder(fov, aspectRatio);
        QWidget::setTabOrder(aspectRatio, nearPlane);
        QWidget::setTabOrder(nearPlane, farPlane);
        QWidget::setTabOrder(farPlane, infiniteFar);

        retranslateUi(ProjectionGuessDialog);

        QMetaObject::connectSlotsByName(ProjectionGuessDialog);
    } // setupUi

    void retranslateUi(QDialog *ProjectionGuessDialog)
    {
        ProjectionGuessDialog->setWindowTitle(QCoreApplication::translate("ProjectionGuessDialog", "Vertex Projection Configuration", nullptr));
        label->setText(QCoreApplication::translate("ProjectionGuessDialog", "<html><head/><body><p>Configure your application's projection matrix used for final vertex transform, which will be used to unproject rasterized vertices into world space.</p><p>Some parameters can be empty, which will use an estimate/guess based on the current mesh data.</p><p>For reverse-Z you can enable an infinite far plane.</p></body></html>", nullptr));
        aspectRatio->setPlaceholderText(QCoreApplication::translate("ProjectionGuessDialog", "Auto", nullptr));
        nearPlane->setPlaceholderText(QCoreApplication::translate("ProjectionGuessDialog", "Auto", nullptr));
        label_6->setText(QCoreApplication::translate("ProjectionGuessDialog", "Far Plane:", nullptr));
        label_4->setText(QCoreApplication::translate("ProjectionGuessDialog", "Aspect Ratio:", nullptr));
        farPlane->setPlaceholderText(QCoreApplication::translate("ProjectionGuessDialog", "Auto", nullptr));
        label_2->setText(QCoreApplication::translate("ProjectionGuessDialog", "Matrix type", nullptr));
        label_5->setText(QCoreApplication::translate("ProjectionGuessDialog", "Near Plane:", nullptr));
        label_3->setText(QCoreApplication::translate("ProjectionGuessDialog", "FOV:", nullptr));
        matrixType->setItemText(0, QCoreApplication::translate("ProjectionGuessDialog", "Perspective", nullptr));
        matrixType->setItemText(1, QCoreApplication::translate("ProjectionGuessDialog", "Orthographic", nullptr));

        infiniteFar->setText(QCoreApplication::translate("ProjectionGuessDialog", "Infinite", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProjectionGuessDialog: public Ui_ProjectionGuessDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROJECTIONGUESSDIALOG_H
