/****************************************************************************
** Meta object code from reading C++ file 'BufferViewer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/BufferViewer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BufferViewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferViewer_t {
    QByteArrayData data[64];
    char stringdata0[1224];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewer_t qt_meta_stringdata_BufferViewer = {
    {
QT_MOC_LITERAL(0, 0, 12), // "BufferViewer"
QT_MOC_LITERAL(1, 13, 28), // "on_outputTabs_currentChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 5), // "index"
QT_MOC_LITERAL(4, 49, 22), // "on_resetCamera_clicked"
QT_MOC_LITERAL(5, 72, 24), // "on_autofitCamera_clicked"
QT_MOC_LITERAL(6, 97, 25), // "on_toggleControls_toggled"
QT_MOC_LITERAL(7, 123, 7), // "checked"
QT_MOC_LITERAL(8, 131, 20), // "on_syncViews_toggled"
QT_MOC_LITERAL(9, 152, 22), // "on_showPadding_toggled"
QT_MOC_LITERAL(10, 175, 26), // "on_resourceDetails_clicked"
QT_MOC_LITERAL(11, 202, 25), // "on_highlightVerts_toggled"
QT_MOC_LITERAL(12, 228, 33), // "on_vtxExploderSlider_valueCha..."
QT_MOC_LITERAL(13, 262, 5), // "value"
QT_MOC_LITERAL(14, 268, 24), // "on_exploderReset_clicked"
QT_MOC_LITERAL(15, 293, 29), // "on_exploderScale_valueChanged"
QT_MOC_LITERAL(16, 323, 26), // "on_wireframeRender_toggled"
QT_MOC_LITERAL(17, 350, 36), // "on_visualisation_currentIndex..."
QT_MOC_LITERAL(18, 387, 32), // "on_drawRange_currentIndexChanged"
QT_MOC_LITERAL(19, 420, 34), // "on_controlType_currentIndexCh..."
QT_MOC_LITERAL(20, 455, 24), // "on_camSpeed_valueChanged"
QT_MOC_LITERAL(21, 480, 24), // "on_instance_valueChanged"
QT_MOC_LITERAL(22, 505, 25), // "on_viewIndex_valueChanged"
QT_MOC_LITERAL(23, 531, 25), // "on_rowOffset_valueChanged"
QT_MOC_LITERAL(24, 557, 30), // "on_byteRangeStart_valueChanged"
QT_MOC_LITERAL(25, 588, 31), // "on_byteRangeLength_valueChanged"
QT_MOC_LITERAL(26, 620, 39), // "on_axisMappingCombo_currentIn..."
QT_MOC_LITERAL(27, 660, 28), // "on_axisMappingButton_clicked"
QT_MOC_LITERAL(28, 689, 20), // "on_setFormat_toggled"
QT_MOC_LITERAL(29, 710, 32), // "on_resetMeshFilterButton_clicked"
QT_MOC_LITERAL(30, 743, 24), // "on_camParameters_clicked"
QT_MOC_LITERAL(31, 768, 22), // "on_guessButton_clicked"
QT_MOC_LITERAL(32, 791, 16), // "render_mouseMove"
QT_MOC_LITERAL(33, 808, 12), // "QMouseEvent*"
QT_MOC_LITERAL(34, 821, 1), // "e"
QT_MOC_LITERAL(35, 823, 14), // "render_clicked"
QT_MOC_LITERAL(36, 838, 16), // "render_unclicked"
QT_MOC_LITERAL(37, 855, 17), // "render_mouseWheel"
QT_MOC_LITERAL(38, 873, 12), // "QWheelEvent*"
QT_MOC_LITERAL(39, 886, 15), // "render_keyPress"
QT_MOC_LITERAL(40, 902, 10), // "QKeyEvent*"
QT_MOC_LITERAL(41, 913, 17), // "render_keyRelease"
QT_MOC_LITERAL(42, 931, 12), // "render_timer"
QT_MOC_LITERAL(43, 944, 13), // "data_selected"
QT_MOC_LITERAL(44, 958, 14), // "QItemSelection"
QT_MOC_LITERAL(45, 973, 8), // "selected"
QT_MOC_LITERAL(46, 982, 10), // "deselected"
QT_MOC_LITERAL(47, 993, 13), // "data_scrolled"
QT_MOC_LITERAL(48, 1007, 6), // "scroll"
QT_MOC_LITERAL(49, 1014, 13), // "processFormat"
QT_MOC_LITERAL(50, 1028, 6), // "format"
QT_MOC_LITERAL(51, 1035, 23), // "updateExportActionNames"
QT_MOC_LITERAL(52, 1059, 10), // "exportData"
QT_MOC_LITERAL(53, 1070, 12), // "BufferExport"
QT_MOC_LITERAL(54, 1083, 6), // "params"
QT_MOC_LITERAL(55, 1090, 11), // "debugVertex"
QT_MOC_LITERAL(56, 1102, 15), // "debugMeshThread"
QT_MOC_LITERAL(57, 1118, 28), // "meshDebugSelector_beginDebug"
QT_MOC_LITERAL(58, 1147, 25), // "rdcfixedarray<uint32_t,3>"
QT_MOC_LITERAL(59, 1173, 5), // "group"
QT_MOC_LITERAL(60, 1179, 6), // "thread"
QT_MOC_LITERAL(61, 1186, 21), // "fixedVars_contextMenu"
QT_MOC_LITERAL(62, 1208, 3), // "pos"
QT_MOC_LITERAL(63, 1212, 11) // "persistData"

    },
    "BufferViewer\0on_outputTabs_currentChanged\0"
    "\0index\0on_resetCamera_clicked\0"
    "on_autofitCamera_clicked\0"
    "on_toggleControls_toggled\0checked\0"
    "on_syncViews_toggled\0on_showPadding_toggled\0"
    "on_resourceDetails_clicked\0"
    "on_highlightVerts_toggled\0"
    "on_vtxExploderSlider_valueChanged\0"
    "value\0on_exploderReset_clicked\0"
    "on_exploderScale_valueChanged\0"
    "on_wireframeRender_toggled\0"
    "on_visualisation_currentIndexChanged\0"
    "on_drawRange_currentIndexChanged\0"
    "on_controlType_currentIndexChanged\0"
    "on_camSpeed_valueChanged\0"
    "on_instance_valueChanged\0"
    "on_viewIndex_valueChanged\0"
    "on_rowOffset_valueChanged\0"
    "on_byteRangeStart_valueChanged\0"
    "on_byteRangeLength_valueChanged\0"
    "on_axisMappingCombo_currentIndexChanged\0"
    "on_axisMappingButton_clicked\0"
    "on_setFormat_toggled\0"
    "on_resetMeshFilterButton_clicked\0"
    "on_camParameters_clicked\0"
    "on_guessButton_clicked\0render_mouseMove\0"
    "QMouseEvent*\0e\0render_clicked\0"
    "render_unclicked\0render_mouseWheel\0"
    "QWheelEvent*\0render_keyPress\0QKeyEvent*\0"
    "render_keyRelease\0render_timer\0"
    "data_selected\0QItemSelection\0selected\0"
    "deselected\0data_scrolled\0scroll\0"
    "processFormat\0format\0updateExportActionNames\0"
    "exportData\0BufferExport\0params\0"
    "debugVertex\0debugMeshThread\0"
    "meshDebugSelector_beginDebug\0"
    "rdcfixedarray<uint32_t,3>\0group\0thread\0"
    "fixedVars_contextMenu\0pos\0persistData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      43,   14, // methods
       1,  338, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  229,    2, 0x08 /* Private */,
       4,    0,  232,    2, 0x08 /* Private */,
       5,    0,  233,    2, 0x08 /* Private */,
       6,    1,  234,    2, 0x08 /* Private */,
       8,    1,  237,    2, 0x08 /* Private */,
       9,    1,  240,    2, 0x08 /* Private */,
      10,    0,  243,    2, 0x08 /* Private */,
      11,    1,  244,    2, 0x08 /* Private */,
      12,    1,  247,    2, 0x08 /* Private */,
      14,    0,  250,    2, 0x08 /* Private */,
      15,    1,  251,    2, 0x08 /* Private */,
      16,    1,  254,    2, 0x08 /* Private */,
      17,    1,  257,    2, 0x08 /* Private */,
      18,    1,  260,    2, 0x08 /* Private */,
      19,    1,  263,    2, 0x08 /* Private */,
      20,    1,  266,    2, 0x08 /* Private */,
      21,    1,  269,    2, 0x08 /* Private */,
      22,    1,  272,    2, 0x08 /* Private */,
      23,    1,  275,    2, 0x08 /* Private */,
      24,    1,  278,    2, 0x08 /* Private */,
      25,    1,  281,    2, 0x08 /* Private */,
      26,    1,  284,    2, 0x08 /* Private */,
      27,    0,  287,    2, 0x08 /* Private */,
      28,    1,  288,    2, 0x08 /* Private */,
      29,    0,  291,    2, 0x08 /* Private */,
      30,    0,  292,    2, 0x08 /* Private */,
      31,    0,  293,    2, 0x08 /* Private */,
      32,    1,  294,    2, 0x08 /* Private */,
      35,    1,  297,    2, 0x08 /* Private */,
      36,    1,  300,    2, 0x08 /* Private */,
      37,    1,  303,    2, 0x08 /* Private */,
      39,    1,  306,    2, 0x08 /* Private */,
      41,    1,  309,    2, 0x08 /* Private */,
      42,    0,  312,    2, 0x08 /* Private */,
      43,    2,  313,    2, 0x08 /* Private */,
      47,    1,  318,    2, 0x08 /* Private */,
      49,    1,  321,    2, 0x08 /* Private */,
      51,    0,  324,    2, 0x08 /* Private */,
      52,    1,  325,    2, 0x08 /* Private */,
      55,    0,  328,    2, 0x08 /* Private */,
      56,    0,  329,    2, 0x08 /* Private */,
      57,    2,  330,    2, 0x08 /* Private */,
      61,    1,  335,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,   13,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Double,   13,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Double,   13,
    QMetaType::Void, QMetaType::Double,   13,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, 0x80000000 | 38,   34,
    QMetaType::Void, 0x80000000 | 40,   34,
    QMetaType::Void, 0x80000000 | 40,   34,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 44, 0x80000000 | 44,   45,   46,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::QString,   50,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 53,   54,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 58, 0x80000000 | 58,   59,   60,
    QMetaType::Void, QMetaType::QPoint,   62,

 // properties: name, type, flags
      63, QMetaType::QVariant, 0x00090103,

       0        // eod
};

void BufferViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_outputTabs_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->on_resetCamera_clicked(); break;
        case 2: _t->on_autofitCamera_clicked(); break;
        case 3: _t->on_toggleControls_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->on_syncViews_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->on_showPadding_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->on_resourceDetails_clicked(); break;
        case 7: _t->on_highlightVerts_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->on_vtxExploderSlider_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_exploderReset_clicked(); break;
        case 10: _t->on_exploderScale_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 11: _t->on_wireframeRender_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->on_visualisation_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->on_drawRange_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->on_controlType_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->on_camSpeed_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 16: _t->on_instance_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_viewIndex_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->on_rowOffset_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->on_byteRangeStart_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 20: _t->on_byteRangeLength_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 21: _t->on_axisMappingCombo_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->on_axisMappingButton_clicked(); break;
        case 23: _t->on_setFormat_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->on_resetMeshFilterButton_clicked(); break;
        case 25: _t->on_camParameters_clicked(); break;
        case 26: _t->on_guessButton_clicked(); break;
        case 27: _t->render_mouseMove((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 28: _t->render_clicked((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 29: _t->render_unclicked((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 30: _t->render_mouseWheel((*reinterpret_cast< QWheelEvent*(*)>(_a[1]))); break;
        case 31: _t->render_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 32: _t->render_keyRelease((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 33: _t->render_timer(); break;
        case 34: _t->data_selected((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 35: _t->data_scrolled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->processFormat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 37: _t->updateExportActionNames(); break;
        case 38: _t->exportData((*reinterpret_cast< const BufferExport(*)>(_a[1]))); break;
        case 39: _t->debugVertex(); break;
        case 40: _t->debugMeshThread(); break;
        case 41: _t->meshDebugSelector_beginDebug((*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[1])),(*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[2]))); break;
        case 42: _t->fixedVars_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BufferViewer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->persistData(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<BufferViewer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPersistData(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject BufferViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_BufferViewer.data,
    qt_meta_data_BufferViewer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IBufferViewer"))
        return static_cast< IBufferViewer*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QFrame::qt_metacast(_clname);
}

int BufferViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 43;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
