/****************************************************************************
** Meta object code from reading C++ file 'ScintillaEditBase.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/3rdparty/scintilla/qt/ScintillaEditBase/ScintillaEditBase.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ScintillaEditBase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ScintillaEditBase_t {
    QByteArrayData data[72];
    char stringdata0[770];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ScintillaEditBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ScintillaEditBase_t qt_meta_stringdata_ScintillaEditBase = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ScintillaEditBase"
QT_MOC_LITERAL(1, 18, 18), // "horizontalScrolled"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 5), // "value"
QT_MOC_LITERAL(4, 44, 16), // "verticalScrolled"
QT_MOC_LITERAL(5, 61, 22), // "horizontalRangeChanged"
QT_MOC_LITERAL(6, 84, 3), // "max"
QT_MOC_LITERAL(7, 88, 4), // "page"
QT_MOC_LITERAL(8, 93, 20), // "verticalRangeChanged"
QT_MOC_LITERAL(9, 114, 12), // "notifyChange"
QT_MOC_LITERAL(10, 127, 10), // "linesAdded"
QT_MOC_LITERAL(11, 138, 11), // "aboutToCopy"
QT_MOC_LITERAL(12, 150, 10), // "QMimeData*"
QT_MOC_LITERAL(13, 161, 4), // "data"
QT_MOC_LITERAL(14, 166, 11), // "styleNeeded"
QT_MOC_LITERAL(15, 178, 8), // "position"
QT_MOC_LITERAL(16, 187, 9), // "charAdded"
QT_MOC_LITERAL(17, 197, 2), // "ch"
QT_MOC_LITERAL(18, 200, 16), // "savePointChanged"
QT_MOC_LITERAL(19, 217, 5), // "dirty"
QT_MOC_LITERAL(20, 223, 21), // "modifyAttemptReadOnly"
QT_MOC_LITERAL(21, 245, 3), // "key"
QT_MOC_LITERAL(22, 249, 11), // "doubleClick"
QT_MOC_LITERAL(23, 261, 4), // "line"
QT_MOC_LITERAL(24, 266, 8), // "updateUi"
QT_MOC_LITERAL(25, 275, 8), // "modified"
QT_MOC_LITERAL(26, 284, 4), // "type"
QT_MOC_LITERAL(27, 289, 6), // "length"
QT_MOC_LITERAL(28, 296, 4), // "text"
QT_MOC_LITERAL(29, 301, 7), // "foldNow"
QT_MOC_LITERAL(30, 309, 8), // "foldPrev"
QT_MOC_LITERAL(31, 318, 11), // "macroRecord"
QT_MOC_LITERAL(32, 330, 7), // "message"
QT_MOC_LITERAL(33, 338, 6), // "uptr_t"
QT_MOC_LITERAL(34, 345, 6), // "wParam"
QT_MOC_LITERAL(35, 352, 6), // "sptr_t"
QT_MOC_LITERAL(36, 359, 6), // "lParam"
QT_MOC_LITERAL(37, 366, 13), // "marginClicked"
QT_MOC_LITERAL(38, 380, 9), // "modifiers"
QT_MOC_LITERAL(39, 390, 6), // "margin"
QT_MOC_LITERAL(40, 397, 15), // "textAreaClicked"
QT_MOC_LITERAL(41, 413, 9), // "needShown"
QT_MOC_LITERAL(42, 423, 7), // "painted"
QT_MOC_LITERAL(43, 431, 17), // "userListSelection"
QT_MOC_LITERAL(44, 449, 10), // "uriDropped"
QT_MOC_LITERAL(45, 460, 10), // "dwellStart"
QT_MOC_LITERAL(46, 471, 1), // "x"
QT_MOC_LITERAL(47, 473, 1), // "y"
QT_MOC_LITERAL(48, 475, 8), // "dwellEnd"
QT_MOC_LITERAL(49, 484, 4), // "zoom"
QT_MOC_LITERAL(50, 489, 12), // "hotSpotClick"
QT_MOC_LITERAL(51, 502, 18), // "hotSpotDoubleClick"
QT_MOC_LITERAL(52, 521, 12), // "callTipClick"
QT_MOC_LITERAL(53, 534, 21), // "autoCompleteSelection"
QT_MOC_LITERAL(54, 556, 21), // "autoCompleteCancelled"
QT_MOC_LITERAL(55, 578, 6), // "notify"
QT_MOC_LITERAL(56, 585, 15), // "SCNotification*"
QT_MOC_LITERAL(57, 601, 4), // "pscn"
QT_MOC_LITERAL(58, 606, 7), // "command"
QT_MOC_LITERAL(59, 614, 13), // "buttonPressed"
QT_MOC_LITERAL(60, 628, 12), // "QMouseEvent*"
QT_MOC_LITERAL(61, 641, 5), // "event"
QT_MOC_LITERAL(62, 647, 14), // "buttonReleased"
QT_MOC_LITERAL(63, 662, 10), // "keyPressed"
QT_MOC_LITERAL(64, 673, 10), // "QKeyEvent*"
QT_MOC_LITERAL(65, 684, 7), // "resized"
QT_MOC_LITERAL(66, 692, 16), // "scrollHorizontal"
QT_MOC_LITERAL(67, 709, 14), // "scrollVertical"
QT_MOC_LITERAL(68, 724, 12), // "notifyParent"
QT_MOC_LITERAL(69, 737, 14), // "SCNotification"
QT_MOC_LITERAL(70, 752, 3), // "scn"
QT_MOC_LITERAL(71, 756, 13) // "event_command"

    },
    "ScintillaEditBase\0horizontalScrolled\0"
    "\0value\0verticalScrolled\0horizontalRangeChanged\0"
    "max\0page\0verticalRangeChanged\0"
    "notifyChange\0linesAdded\0aboutToCopy\0"
    "QMimeData*\0data\0styleNeeded\0position\0"
    "charAdded\0ch\0savePointChanged\0dirty\0"
    "modifyAttemptReadOnly\0key\0doubleClick\0"
    "line\0updateUi\0modified\0type\0length\0"
    "text\0foldNow\0foldPrev\0macroRecord\0"
    "message\0uptr_t\0wParam\0sptr_t\0lParam\0"
    "marginClicked\0modifiers\0margin\0"
    "textAreaClicked\0needShown\0painted\0"
    "userListSelection\0uriDropped\0dwellStart\0"
    "x\0y\0dwellEnd\0zoom\0hotSpotClick\0"
    "hotSpotDoubleClick\0callTipClick\0"
    "autoCompleteSelection\0autoCompleteCancelled\0"
    "notify\0SCNotification*\0pscn\0command\0"
    "buttonPressed\0QMouseEvent*\0event\0"
    "buttonReleased\0keyPressed\0QKeyEvent*\0"
    "resized\0scrollHorizontal\0scrollVertical\0"
    "notifyParent\0SCNotification\0scn\0"
    "event_command"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ScintillaEditBase[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      40,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      36,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  214,    2, 0x06 /* Public */,
       4,    1,  217,    2, 0x06 /* Public */,
       5,    2,  220,    2, 0x06 /* Public */,
       8,    2,  225,    2, 0x06 /* Public */,
       9,    0,  230,    2, 0x06 /* Public */,
      10,    1,  231,    2, 0x06 /* Public */,
      11,    1,  234,    2, 0x06 /* Public */,
      14,    1,  237,    2, 0x06 /* Public */,
      16,    1,  240,    2, 0x06 /* Public */,
      18,    1,  243,    2, 0x06 /* Public */,
      20,    0,  246,    2, 0x06 /* Public */,
      21,    1,  247,    2, 0x06 /* Public */,
      22,    2,  250,    2, 0x06 /* Public */,
      24,    0,  255,    2, 0x06 /* Public */,
      25,    8,  256,    2, 0x06 /* Public */,
      31,    3,  273,    2, 0x06 /* Public */,
      37,    3,  280,    2, 0x06 /* Public */,
      40,    2,  287,    2, 0x06 /* Public */,
      41,    2,  292,    2, 0x06 /* Public */,
      42,    0,  297,    2, 0x06 /* Public */,
      43,    0,  298,    2, 0x06 /* Public */,
      44,    0,  299,    2, 0x06 /* Public */,
      45,    2,  300,    2, 0x06 /* Public */,
      48,    2,  305,    2, 0x06 /* Public */,
      49,    1,  310,    2, 0x06 /* Public */,
      50,    2,  313,    2, 0x06 /* Public */,
      51,    2,  318,    2, 0x06 /* Public */,
      52,    0,  323,    2, 0x06 /* Public */,
      53,    2,  324,    2, 0x06 /* Public */,
      54,    0,  329,    2, 0x06 /* Public */,
      55,    1,  330,    2, 0x06 /* Public */,
      58,    2,  333,    2, 0x06 /* Public */,
      59,    1,  338,    2, 0x06 /* Public */,
      62,    1,  341,    2, 0x06 /* Public */,
      63,    1,  344,    2, 0x06 /* Public */,
      65,    0,  347,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      66,    1,  348,    2, 0x0a /* Public */,
      67,    1,  351,    2, 0x0a /* Public */,
      68,    1,  354,    2, 0x0a /* Public */,
      71,    2,  357,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    6,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    6,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   15,   23,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::QByteArray, QMetaType::Int, QMetaType::Int, QMetaType::Int,   26,   15,   27,   10,   28,   23,   29,   30,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 33, 0x80000000 | 35,   32,   34,   36,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   15,   38,   39,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   23,   38,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   15,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   46,   47,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   46,   47,
    QMetaType::Void, QMetaType::Int,   49,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   15,   38,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   15,   38,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   15,   28,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 56,   57,
    QMetaType::Void, 0x80000000 | 33, 0x80000000 | 35,   34,   36,
    QMetaType::Void, 0x80000000 | 60,   61,
    QMetaType::Void, 0x80000000 | 60,   61,
    QMetaType::Void, 0x80000000 | 64,   61,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 69,   70,
    QMetaType::Void, 0x80000000 | 33, 0x80000000 | 35,   34,   36,

       0        // eod
};

void ScintillaEditBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ScintillaEditBase *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->horizontalScrolled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->verticalScrolled((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->horizontalRangeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->verticalRangeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->notifyChange(); break;
        case 5: _t->linesAdded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->aboutToCopy((*reinterpret_cast< QMimeData*(*)>(_a[1]))); break;
        case 7: _t->styleNeeded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->charAdded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->savePointChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->modifyAttemptReadOnly(); break;
        case 11: _t->key((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->doubleClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->updateUi(); break;
        case 14: _t->modified((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QByteArray(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< int(*)>(_a[8]))); break;
        case 15: _t->macroRecord((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uptr_t(*)>(_a[2])),(*reinterpret_cast< sptr_t(*)>(_a[3]))); break;
        case 16: _t->marginClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 17: _t->textAreaClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 18: _t->needShown((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 19: _t->painted(); break;
        case 20: _t->userListSelection(); break;
        case 21: _t->uriDropped(); break;
        case 22: _t->dwellStart((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 23: _t->dwellEnd((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 24: _t->zoom((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->hotSpotClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 26: _t->hotSpotDoubleClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 27: _t->callTipClick(); break;
        case 28: _t->autoCompleteSelection((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 29: _t->autoCompleteCancelled(); break;
        case 30: _t->notify((*reinterpret_cast< SCNotification*(*)>(_a[1]))); break;
        case 31: _t->command((*reinterpret_cast< uptr_t(*)>(_a[1])),(*reinterpret_cast< sptr_t(*)>(_a[2]))); break;
        case 32: _t->buttonPressed((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 33: _t->buttonReleased((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 34: _t->keyPressed((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 35: _t->resized(); break;
        case 36: _t->scrollHorizontal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->scrollVertical((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 38: _t->notifyParent((*reinterpret_cast< SCNotification(*)>(_a[1]))); break;
        case 39: _t->event_command((*reinterpret_cast< uptr_t(*)>(_a[1])),(*reinterpret_cast< sptr_t(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMimeData* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::horizontalScrolled)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::verticalScrolled)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::horizontalRangeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::verticalRangeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::notifyChange)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::linesAdded)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(QMimeData * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::aboutToCopy)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::styleNeeded)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::charAdded)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::savePointChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::modifyAttemptReadOnly)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::key)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::doubleClick)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::updateUi)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int , int , int , const QByteArray & , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::modified)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , uptr_t , sptr_t );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::macroRecord)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::marginClicked)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::textAreaClicked)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::needShown)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::painted)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::userListSelection)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::uriDropped)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::dwellStart)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::dwellEnd)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::zoom)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::hotSpotClick)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::hotSpotDoubleClick)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::callTipClick)) {
                *result = 27;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::autoCompleteSelection)) {
                *result = 28;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::autoCompleteCancelled)) {
                *result = 29;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(SCNotification * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::notify)) {
                *result = 30;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(uptr_t , sptr_t );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::command)) {
                *result = 31;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(QMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::buttonPressed)) {
                *result = 32;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(QMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::buttonReleased)) {
                *result = 33;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)(QKeyEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::keyPressed)) {
                *result = 34;
                return;
            }
        }
        {
            using _t = void (ScintillaEditBase::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ScintillaEditBase::resized)) {
                *result = 35;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ScintillaEditBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractScrollArea::staticMetaObject>(),
    qt_meta_stringdata_ScintillaEditBase.data,
    qt_meta_data_ScintillaEditBase,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ScintillaEditBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScintillaEditBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ScintillaEditBase.stringdata0))
        return static_cast<void*>(this);
    return QAbstractScrollArea::qt_metacast(_clname);
}

int ScintillaEditBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    return _id;
}

// SIGNAL 0
void ScintillaEditBase::horizontalScrolled(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ScintillaEditBase::verticalScrolled(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ScintillaEditBase::horizontalRangeChanged(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ScintillaEditBase::verticalRangeChanged(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void ScintillaEditBase::notifyChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ScintillaEditBase::linesAdded(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void ScintillaEditBase::aboutToCopy(QMimeData * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void ScintillaEditBase::styleNeeded(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void ScintillaEditBase::charAdded(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void ScintillaEditBase::savePointChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void ScintillaEditBase::modifyAttemptReadOnly()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ScintillaEditBase::key(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void ScintillaEditBase::doubleClick(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void ScintillaEditBase::updateUi()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ScintillaEditBase::modified(int _t1, int _t2, int _t3, int _t4, const QByteArray & _t5, int _t6, int _t7, int _t8)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t8))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void ScintillaEditBase::macroRecord(int _t1, uptr_t _t2, sptr_t _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void ScintillaEditBase::marginClicked(int _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void ScintillaEditBase::textAreaClicked(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void ScintillaEditBase::needShown(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void ScintillaEditBase::painted()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void ScintillaEditBase::userListSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void ScintillaEditBase::uriDropped()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void ScintillaEditBase::dwellStart(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void ScintillaEditBase::dwellEnd(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void ScintillaEditBase::zoom(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void ScintillaEditBase::hotSpotClick(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void ScintillaEditBase::hotSpotDoubleClick(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void ScintillaEditBase::callTipClick()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void ScintillaEditBase::autoCompleteSelection(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 28, _a);
}

// SIGNAL 29
void ScintillaEditBase::autoCompleteCancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void ScintillaEditBase::notify(SCNotification * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 30, _a);
}

// SIGNAL 31
void ScintillaEditBase::command(uptr_t _t1, sptr_t _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 31, _a);
}

// SIGNAL 32
void ScintillaEditBase::buttonPressed(QMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 32, _a);
}

// SIGNAL 33
void ScintillaEditBase::buttonReleased(QMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 33, _a);
}

// SIGNAL 34
void ScintillaEditBase::keyPressed(QKeyEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 34, _a);
}

// SIGNAL 35
void ScintillaEditBase::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
