/****************************************************************************
** Meta object code from reading C++ file 'RDTreeView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/Extended/RDTreeView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RDTreeView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RDTreeViewDelegate_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTreeViewDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTreeViewDelegate_t qt_meta_stringdata_RDTreeViewDelegate = {
    {
QT_MOC_LITERAL(0, 0, 18) // "RDTreeViewDelegate"

    },
    "RDTreeViewDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTreeViewDelegate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void RDTreeViewDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RDTreeViewDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<RichTextViewDelegate::staticMetaObject>(),
    qt_meta_stringdata_RDTreeViewDelegate.data,
    qt_meta_data_RDTreeViewDelegate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTreeViewDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTreeViewDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTreeViewDelegate.stringdata0))
        return static_cast<void*>(this);
    return RichTextViewDelegate::qt_metacast(_clname);
}

int RDTreeViewDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = RichTextViewDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_RDTipLabel_t {
    QByteArrayData data[1];
    char stringdata0[11];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTipLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTipLabel_t qt_meta_stringdata_RDTipLabel = {
    {
QT_MOC_LITERAL(0, 0, 10) // "RDTipLabel"

    },
    "RDTipLabel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTipLabel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void RDTipLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RDTipLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_meta_stringdata_RDTipLabel.data,
    qt_meta_data_RDTipLabel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTipLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTipLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTipLabel.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ITreeViewTipDisplay"))
        return static_cast< ITreeViewTipDisplay*>(this);
    return QLabel::qt_metacast(_clname);
}

int RDTipLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_RDTreeView_t {
    QByteArrayData data[28];
    char stringdata0[345];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTreeView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTreeView_t qt_meta_stringdata_RDTreeView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "RDTreeView"
QT_MOC_LITERAL(1, 11, 5), // "leave"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 7), // "QEvent*"
QT_MOC_LITERAL(4, 26, 1), // "e"
QT_MOC_LITERAL(5, 28, 8), // "keyPress"
QT_MOC_LITERAL(6, 37, 10), // "QKeyEvent*"
QT_MOC_LITERAL(7, 48, 17), // "customContextMenu"
QT_MOC_LITERAL(8, 66, 11), // "QModelIndex"
QT_MOC_LITERAL(9, 78, 5), // "index"
QT_MOC_LITERAL(10, 84, 6), // "QMenu*"
QT_MOC_LITERAL(11, 91, 4), // "menu"
QT_MOC_LITERAL(12, 96, 19), // "modelAboutToBeReset"
QT_MOC_LITERAL(13, 116, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(14, 137, 6), // "parent"
QT_MOC_LITERAL(15, 144, 5), // "first"
QT_MOC_LITERAL(16, 150, 4), // "last"
QT_MOC_LITERAL(17, 155, 23), // "columnsAboutToBeRemoved"
QT_MOC_LITERAL(18, 179, 18), // "rowsAboutToBeMoved"
QT_MOC_LITERAL(19, 198, 12), // "sourceParent"
QT_MOC_LITERAL(20, 211, 11), // "sourceStart"
QT_MOC_LITERAL(21, 223, 9), // "sourceEnd"
QT_MOC_LITERAL(22, 233, 17), // "destinationParent"
QT_MOC_LITERAL(23, 251, 14), // "destinationRow"
QT_MOC_LITERAL(24, 266, 21), // "columnsAboutToBeMoved"
QT_MOC_LITERAL(25, 288, 17), // "destinationColumn"
QT_MOC_LITERAL(26, 306, 22), // "customCopyPasteHandler"
QT_MOC_LITERAL(27, 329, 15) // "instantTooltips"

    },
    "RDTreeView\0leave\0\0QEvent*\0e\0keyPress\0"
    "QKeyEvent*\0customContextMenu\0QModelIndex\0"
    "index\0QMenu*\0menu\0modelAboutToBeReset\0"
    "rowsAboutToBeRemoved\0parent\0first\0"
    "last\0columnsAboutToBeRemoved\0"
    "rowsAboutToBeMoved\0sourceParent\0"
    "sourceStart\0sourceEnd\0destinationParent\0"
    "destinationRow\0columnsAboutToBeMoved\0"
    "destinationColumn\0customCopyPasteHandler\0"
    "instantTooltips"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTreeView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       2,  102, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       5,    1,   57,    2, 0x06 /* Public */,
       7,    2,   60,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   65,    2, 0x08 /* Private */,
      13,    3,   66,    2, 0x08 /* Private */,
      17,    3,   73,    2, 0x08 /* Private */,
      18,    5,   80,    2, 0x08 /* Private */,
      24,    5,   91,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    4,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 10,    9,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int, QMetaType::Int,   14,   15,   16,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int, QMetaType::Int,   14,   15,   16,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int, QMetaType::Int, 0x80000000 | 8, QMetaType::Int,   19,   20,   21,   22,   23,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int, QMetaType::Int, 0x80000000 | 8, QMetaType::Int,   19,   20,   21,   22,   25,

 // properties: name, type, flags
      26, QMetaType::Bool, 0x00095103,
      27, QMetaType::Bool, 0x00095103,

       0        // eod
};

void RDTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RDTreeView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->leave((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 1: _t->keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 2: _t->customContextMenu((*reinterpret_cast< QModelIndex(*)>(_a[1])),(*reinterpret_cast< QMenu*(*)>(_a[2]))); break;
        case 3: _t->modelAboutToBeReset(); break;
        case 4: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->columnsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->rowsAboutToBeMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 7: _t->columnsAboutToBeMoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< const QModelIndex(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RDTreeView::*)(QEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeView::leave)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (RDTreeView::*)(QKeyEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeView::keyPress)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (RDTreeView::*)(QModelIndex , QMenu * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeView::customContextMenu)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<RDTreeView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->customCopyPasteHandler(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->instantTooltips(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<RDTreeView *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCustomCopyPasteHandler(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setInstantTooltips(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject RDTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_meta_stringdata_RDTreeView.data,
    qt_meta_data_RDTreeView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTreeView.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int RDTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void RDTreeView::leave(QEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void RDTreeView::keyPress(QKeyEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void RDTreeView::customContextMenu(QModelIndex _t1, QMenu * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
