/******************************************************************************
 * The MIT License (MIT)
 *
 * Copyright (c) 2018-2026 Baldur Karlsson
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 ******************************************************************************/

#pragma once

#include <QGroupBox>

class CollapseGroupBox : public QGroupBox
{
  Q_OBJECT

public:
  explicit CollapseGroupBox(QWidget *parent = 0);
  ~CollapseGroupBox();

  // not virtual sadly, but at least we can catch code that calls via a CollapseGroupBox*
  void setMaximumSize(const QSize &size);
  void setMaximumSize(int maxw, int maxh) { setMaximumSize(QSize(maxw, maxh)); }
  void setMaximumHeight(int maxh);

  void setCollapsed(bool coll);
  bool collapsed() { return m_collapsed; }
protected:
  void paintEvent(QPaintEvent *) override;
  void mouseReleaseEvent(QMouseEvent *event) override;

private:
  bool m_collapsed = false;

  int m_prevMaxHeight = 0;
};
