/****************************************************************************
** Meta object code from reading C++ file 'PythonContext.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Code/pyrenderdoc/PythonContext.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PythonContext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PythonContext_t {
    QByteArrayData data[25];
    char stringdata0[227];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PythonContext_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PythonContext_t qt_meta_stringdata_PythonContext = {
    {
QT_MOC_LITERAL(0, 0, 13), // "PythonContext"
QT_MOC_LITERAL(1, 14, 9), // "traceLine"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 4), // "file"
QT_MOC_LITERAL(4, 30, 4), // "line"
QT_MOC_LITERAL(5, 35, 9), // "exception"
QT_MOC_LITERAL(6, 45, 4), // "type"
QT_MOC_LITERAL(7, 50, 5), // "value"
QT_MOC_LITERAL(8, 56, 9), // "finalLine"
QT_MOC_LITERAL(9, 66, 14), // "QList<QString>"
QT_MOC_LITERAL(10, 81, 6), // "frames"
QT_MOC_LITERAL(11, 88, 10), // "textOutput"
QT_MOC_LITERAL(12, 99, 10), // "isStdError"
QT_MOC_LITERAL(13, 110, 6), // "output"
QT_MOC_LITERAL(14, 117, 13), // "executeString"
QT_MOC_LITERAL(15, 131, 6), // "source"
QT_MOC_LITERAL(16, 138, 8), // "filename"
QT_MOC_LITERAL(17, 147, 11), // "executeFile"
QT_MOC_LITERAL(18, 159, 9), // "setGlobal"
QT_MOC_LITERAL(19, 169, 11), // "const char*"
QT_MOC_LITERAL(20, 181, 7), // "varName"
QT_MOC_LITERAL(21, 189, 8), // "typeName"
QT_MOC_LITERAL(22, 198, 6), // "object"
QT_MOC_LITERAL(23, 205, 11), // "setPyGlobal"
QT_MOC_LITERAL(24, 217, 9) // "PyObject*"

    },
    "PythonContext\0traceLine\0\0file\0line\0"
    "exception\0type\0value\0finalLine\0"
    "QList<QString>\0frames\0textOutput\0"
    "isStdError\0output\0executeString\0source\0"
    "filename\0executeFile\0setGlobal\0"
    "const char*\0varName\0typeName\0object\0"
    "setPyGlobal\0PyObject*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PythonContext[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x06 /* Public */,
       5,    4,   59,    2, 0x06 /* Public */,
      11,    2,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,   73,    2, 0x0a /* Public */,
      14,    2,   76,    2, 0x0a /* Public */,
      17,    1,   81,    2, 0x0a /* Public */,
      18,    3,   84,    2, 0x0a /* Public */,
      23,    2,   91,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    3,    4,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Int, 0x80000000 | 9,    6,    7,    8,   10,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString,   12,   13,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   16,   15,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 19, QMetaType::VoidStar,   20,   21,   22,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 24,   20,   22,

       0        // eod
};

void PythonContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PythonContext *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->traceLine((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->exception((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< QList<QString>(*)>(_a[4]))); break;
        case 2: _t->textOutput((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->executeString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->executeString((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->executeFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setGlobal((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< const char*(*)>(_a[2])),(*reinterpret_cast< void*(*)>(_a[3]))); break;
        case 7: _t->setPyGlobal((*reinterpret_cast< const char*(*)>(_a[1])),(*reinterpret_cast< PyObject*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PythonContext::*)(const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PythonContext::traceLine)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PythonContext::*)(const QString & , const QString & , int , QList<QString> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PythonContext::exception)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PythonContext::*)(bool , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PythonContext::textOutput)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PythonContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_PythonContext.data,
    qt_meta_data_PythonContext,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PythonContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PythonContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PythonContext.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PythonContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PythonContext::traceLine(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void PythonContext::exception(const QString & _t1, const QString & _t2, int _t3, QList<QString> _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PythonContext::textOutput(bool _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
