/****************************************************************************
** Meta object code from reading C++ file 'LiveCapture.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/LiveCapture.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'LiveCapture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LiveCapture_t {
    QByteArrayData data[31];
    char stringdata0[577];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LiveCapture_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LiveCapture_t qt_meta_stringdata_LiveCapture = {
    {
QT_MOC_LITERAL(0, 0, 11), // "LiveCapture"
QT_MOC_LITERAL(1, 12, 15), // "checkAllowClose"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 32), // "on_captures_itemSelectionChanged"
QT_MOC_LITERAL(4, 62, 24), // "on_captures_mouseClicked"
QT_MOC_LITERAL(5, 87, 12), // "QMouseEvent*"
QT_MOC_LITERAL(6, 100, 1), // "e"
QT_MOC_LITERAL(7, 102, 25), // "on_captures_itemActivated"
QT_MOC_LITERAL(8, 128, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(9, 145, 4), // "item"
QT_MOC_LITERAL(10, 150, 31), // "on_childProcesses_itemActivated"
QT_MOC_LITERAL(11, 182, 34), // "on_triggerImmediateCapture_cl..."
QT_MOC_LITERAL(12, 217, 28), // "on_cycleActiveWindow_clicked"
QT_MOC_LITERAL(13, 246, 32), // "on_triggerDelayedCapture_clicked"
QT_MOC_LITERAL(14, 279, 19), // "on_queueCap_clicked"
QT_MOC_LITERAL(15, 299, 29), // "on_previewSplit_splitterMoved"
QT_MOC_LITERAL(16, 329, 3), // "pos"
QT_MOC_LITERAL(17, 333, 5), // "index"
QT_MOC_LITERAL(18, 339, 18), // "on_apiIcon_clicked"
QT_MOC_LITERAL(19, 358, 5), // "event"
QT_MOC_LITERAL(20, 364, 17), // "captures_keyPress"
QT_MOC_LITERAL(21, 382, 10), // "QKeyEvent*"
QT_MOC_LITERAL(22, 393, 11), // "childUpdate"
QT_MOC_LITERAL(23, 405, 20), // "captureCountdownTick"
QT_MOC_LITERAL(24, 426, 21), // "openCapture_triggered"
QT_MOC_LITERAL(25, 448, 23), // "openNewWindow_triggered"
QT_MOC_LITERAL(26, 472, 21), // "saveCapture_triggered"
QT_MOC_LITERAL(27, 494, 23), // "deleteCapture_triggered"
QT_MOC_LITERAL(28, 518, 21), // "previewToggle_toggled"
QT_MOC_LITERAL(29, 540, 18), // "preview_mouseClick"
QT_MOC_LITERAL(30, 559, 17) // "preview_mouseMove"

    },
    "LiveCapture\0checkAllowClose\0\0"
    "on_captures_itemSelectionChanged\0"
    "on_captures_mouseClicked\0QMouseEvent*\0"
    "e\0on_captures_itemActivated\0"
    "QListWidgetItem*\0item\0"
    "on_childProcesses_itemActivated\0"
    "on_triggerImmediateCapture_clicked\0"
    "on_cycleActiveWindow_clicked\0"
    "on_triggerDelayedCapture_clicked\0"
    "on_queueCap_clicked\0on_previewSplit_splitterMoved\0"
    "pos\0index\0on_apiIcon_clicked\0event\0"
    "captures_keyPress\0QKeyEvent*\0childUpdate\0"
    "captureCountdownTick\0openCapture_triggered\0"
    "openNewWindow_triggered\0saveCapture_triggered\0"
    "deleteCapture_triggered\0previewToggle_toggled\0"
    "preview_mouseClick\0preview_mouseMove"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LiveCapture[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x0a /* Public */,
       3,    0,  120,    2, 0x08 /* Private */,
       4,    1,  121,    2, 0x08 /* Private */,
       7,    1,  124,    2, 0x08 /* Private */,
      10,    1,  127,    2, 0x08 /* Private */,
      11,    0,  130,    2, 0x08 /* Private */,
      12,    0,  131,    2, 0x08 /* Private */,
      13,    0,  132,    2, 0x08 /* Private */,
      14,    0,  133,    2, 0x08 /* Private */,
      15,    2,  134,    2, 0x08 /* Private */,
      18,    1,  139,    2, 0x08 /* Private */,
      20,    1,  142,    2, 0x08 /* Private */,
      22,    0,  145,    2, 0x08 /* Private */,
      23,    0,  146,    2, 0x08 /* Private */,
      24,    0,  147,    2, 0x08 /* Private */,
      25,    0,  148,    2, 0x08 /* Private */,
      26,    0,  149,    2, 0x08 /* Private */,
      27,    0,  150,    2, 0x08 /* Private */,
      28,    1,  151,    2, 0x08 /* Private */,
      29,    1,  154,    2, 0x08 /* Private */,
      30,    1,  157,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   16,   17,
    QMetaType::Void, 0x80000000 | 5,   19,
    QMetaType::Void, 0x80000000 | 21,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,

       0        // eod
};

void LiveCapture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LiveCapture *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->checkAllowClose();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->on_captures_itemSelectionChanged(); break;
        case 2: _t->on_captures_mouseClicked((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 3: _t->on_captures_itemActivated((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 4: _t->on_childProcesses_itemActivated((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 5: _t->on_triggerImmediateCapture_clicked(); break;
        case 6: _t->on_cycleActiveWindow_clicked(); break;
        case 7: _t->on_triggerDelayedCapture_clicked(); break;
        case 8: _t->on_queueCap_clicked(); break;
        case 9: _t->on_previewSplit_splitterMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->on_apiIcon_clicked((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 11: _t->captures_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 12: _t->childUpdate(); break;
        case 13: _t->captureCountdownTick(); break;
        case 14: _t->openCapture_triggered(); break;
        case 15: _t->openNewWindow_triggered(); break;
        case 16: _t->saveCapture_triggered(); break;
        case 17: _t->deleteCapture_triggered(); break;
        case 18: _t->previewToggle_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->preview_mouseClick((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 20: _t->preview_mouseMove((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject LiveCapture::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_LiveCapture.data,
    qt_meta_data_LiveCapture,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LiveCapture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LiveCapture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LiveCapture.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int LiveCapture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
