/****************************************************************************
** Meta object code from reading C++ file 'D3D11PipelineStateViewer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/PipelineState/D3D11PipelineStateViewer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'D3D11PipelineStateViewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_D3D11PipelineStateViewer_t {
    QByteArrayData data[30];
    char stringdata0[509];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_D3D11PipelineStateViewer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_D3D11PipelineStateViewer_t qt_meta_stringdata_D3D11PipelineStateViewer = {
    {
QT_MOC_LITERAL(0, 0, 24), // "D3D11PipelineStateViewer"
QT_MOC_LITERAL(1, 25, 21), // "on_showUnused_toggled"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 7), // "checked"
QT_MOC_LITERAL(4, 56, 20), // "on_showEmpty_toggled"
QT_MOC_LITERAL(5, 77, 21), // "on_exportHTML_clicked"
QT_MOC_LITERAL(6, 99, 19), // "on_meshView_clicked"
QT_MOC_LITERAL(7, 119, 26), // "on_iaLayouts_itemActivated"
QT_MOC_LITERAL(8, 146, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(9, 164, 4), // "item"
QT_MOC_LITERAL(10, 169, 6), // "column"
QT_MOC_LITERAL(11, 176, 26), // "on_iaBuffers_itemActivated"
QT_MOC_LITERAL(12, 203, 22), // "on_iaLayouts_mouseMove"
QT_MOC_LITERAL(13, 226, 12), // "QMouseEvent*"
QT_MOC_LITERAL(14, 239, 5), // "event"
QT_MOC_LITERAL(15, 245, 22), // "on_iaBuffers_mouseMove"
QT_MOC_LITERAL(16, 268, 25), // "on_pipeFlow_stageSelected"
QT_MOC_LITERAL(17, 294, 5), // "index"
QT_MOC_LITERAL(18, 300, 18), // "shaderView_clicked"
QT_MOC_LITERAL(19, 319, 18), // "shaderSave_clicked"
QT_MOC_LITERAL(20, 338, 22), // "resource_itemActivated"
QT_MOC_LITERAL(21, 361, 21), // "cbuffer_itemActivated"
QT_MOC_LITERAL(22, 383, 12), // "vertex_leave"
QT_MOC_LITERAL(23, 396, 7), // "QEvent*"
QT_MOC_LITERAL(24, 404, 1), // "e"
QT_MOC_LITERAL(25, 406, 31), // "on_computeDebugSelector_clicked"
QT_MOC_LITERAL(26, 438, 31), // "computeDebugSelector_beginDebug"
QT_MOC_LITERAL(27, 470, 25), // "rdcfixedarray<uint32_t,3>"
QT_MOC_LITERAL(28, 496, 5), // "group"
QT_MOC_LITERAL(29, 502, 6) // "thread"

    },
    "D3D11PipelineStateViewer\0on_showUnused_toggled\0"
    "\0checked\0on_showEmpty_toggled\0"
    "on_exportHTML_clicked\0on_meshView_clicked\0"
    "on_iaLayouts_itemActivated\0RDTreeWidgetItem*\0"
    "item\0column\0on_iaBuffers_itemActivated\0"
    "on_iaLayouts_mouseMove\0QMouseEvent*\0"
    "event\0on_iaBuffers_mouseMove\0"
    "on_pipeFlow_stageSelected\0index\0"
    "shaderView_clicked\0shaderSave_clicked\0"
    "resource_itemActivated\0cbuffer_itemActivated\0"
    "vertex_leave\0QEvent*\0e\0"
    "on_computeDebugSelector_clicked\0"
    "computeDebugSelector_beginDebug\0"
    "rdcfixedarray<uint32_t,3>\0group\0thread"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_D3D11PipelineStateViewer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x08 /* Private */,
       4,    1,   97,    2, 0x08 /* Private */,
       5,    0,  100,    2, 0x08 /* Private */,
       6,    0,  101,    2, 0x08 /* Private */,
       7,    2,  102,    2, 0x08 /* Private */,
      11,    2,  107,    2, 0x08 /* Private */,
      12,    1,  112,    2, 0x08 /* Private */,
      15,    1,  115,    2, 0x08 /* Private */,
      16,    1,  118,    2, 0x08 /* Private */,
      18,    0,  121,    2, 0x08 /* Private */,
      19,    0,  122,    2, 0x08 /* Private */,
      20,    2,  123,    2, 0x08 /* Private */,
      21,    2,  128,    2, 0x08 /* Private */,
      22,    1,  133,    2, 0x08 /* Private */,
      25,    0,  136,    2, 0x08 /* Private */,
      26,    2,  137,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27, 0x80000000 | 27,   28,   29,

       0        // eod
};

void D3D11PipelineStateViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<D3D11PipelineStateViewer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_showUnused_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->on_showEmpty_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->on_exportHTML_clicked(); break;
        case 3: _t->on_meshView_clicked(); break;
        case 4: _t->on_iaLayouts_itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->on_iaBuffers_itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->on_iaLayouts_mouseMove((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 7: _t->on_iaBuffers_mouseMove((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 8: _t->on_pipeFlow_stageSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->shaderView_clicked(); break;
        case 10: _t->shaderSave_clicked(); break;
        case 11: _t->resource_itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 12: _t->cbuffer_itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->vertex_leave((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        case 14: _t->on_computeDebugSelector_clicked(); break;
        case 15: _t->computeDebugSelector_beginDebug((*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[1])),(*reinterpret_cast< const rdcfixedarray<uint32_t,3>(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject D3D11PipelineStateViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_D3D11PipelineStateViewer.data,
    qt_meta_data_D3D11PipelineStateViewer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *D3D11PipelineStateViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *D3D11PipelineStateViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_D3D11PipelineStateViewer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QFrame::qt_metacast(_clname);
}

int D3D11PipelineStateViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
