/****************************************************************************
** Meta object code from reading C++ file 'ResourceInspector.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/ResourceInspector.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ResourceInspector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ResourceSorterModel_t {
    QByteArrayData data[1];
    char stringdata0[20];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ResourceSorterModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ResourceSorterModel_t qt_meta_stringdata_ResourceSorterModel = {
    {
QT_MOC_LITERAL(0, 0, 19) // "ResourceSorterModel"

    },
    "ResourceSorterModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ResourceSorterModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ResourceSorterModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ResourceSorterModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QCollatorSortFilterProxyModel::staticMetaObject>(),
    qt_meta_stringdata_ResourceSorterModel.data,
    qt_meta_data_ResourceSorterModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ResourceSorterModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourceSorterModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ResourceSorterModel.stringdata0))
        return static_cast<void*>(this);
    return QCollatorSortFilterProxyModel::qt_metacast(_clname);
}

int ResourceSorterModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCollatorSortFilterProxyModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ResourceInspector_t {
    QByteArrayData data[19];
    char stringdata0[381];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ResourceInspector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ResourceInspector_t qt_meta_stringdata_ResourceInspector = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ResourceInspector"
QT_MOC_LITERAL(1, 18, 25), // "on_renameResource_clicked"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 28), // "on_resourceNameEdit_keyPress"
QT_MOC_LITERAL(4, 74, 10), // "QKeyEvent*"
QT_MOC_LITERAL(5, 85, 5), // "event"
QT_MOC_LITERAL(6, 91, 20), // "on_resetName_clicked"
QT_MOC_LITERAL(7, 112, 31), // "on_sortType_currentIndexChanged"
QT_MOC_LITERAL(8, 144, 5), // "index"
QT_MOC_LITERAL(9, 150, 35), // "on_cancelResourceListFilter_c..."
QT_MOC_LITERAL(10, 186, 33), // "on_resourceListFilter_textCha..."
QT_MOC_LITERAL(11, 220, 4), // "text"
QT_MOC_LITERAL(12, 225, 22), // "resource_doubleClicked"
QT_MOC_LITERAL(13, 248, 11), // "QModelIndex"
QT_MOC_LITERAL(14, 260, 25), // "resourceUsage_contextMenu"
QT_MOC_LITERAL(15, 286, 3), // "pos"
QT_MOC_LITERAL(16, 290, 23), // "on_viewContents_clicked"
QT_MOC_LITERAL(17, 314, 30), // "on_resourceUsage_doubleClicked"
QT_MOC_LITERAL(18, 345, 35) // "resourceUsage_SplitByMarker_t..."

    },
    "ResourceInspector\0on_renameResource_clicked\0"
    "\0on_resourceNameEdit_keyPress\0QKeyEvent*\0"
    "event\0on_resetName_clicked\0"
    "on_sortType_currentIndexChanged\0index\0"
    "on_cancelResourceListFilter_clicked\0"
    "on_resourceListFilter_textChanged\0"
    "text\0resource_doubleClicked\0QModelIndex\0"
    "resourceUsage_contextMenu\0pos\0"
    "on_viewContents_clicked\0"
    "on_resourceUsage_doubleClicked\0"
    "resourceUsage_SplitByMarker_toggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ResourceInspector[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x0a /* Public */,
       3,    1,   70,    2, 0x0a /* Public */,
       6,    0,   73,    2, 0x0a /* Public */,
       7,    1,   74,    2, 0x0a /* Public */,
       9,    0,   77,    2, 0x0a /* Public */,
      10,    1,   78,    2, 0x0a /* Public */,
      12,    1,   81,    2, 0x0a /* Public */,
      14,    1,   84,    2, 0x0a /* Public */,
      16,    0,   87,    2, 0x08 /* Private */,
      17,    1,   88,    2, 0x08 /* Private */,
      18,    0,   91,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 13,    8,
    QMetaType::Void, QMetaType::QPoint,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,    8,
    QMetaType::Void,

       0        // eod
};

void ResourceInspector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ResourceInspector *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_renameResource_clicked(); break;
        case 1: _t->on_resourceNameEdit_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 2: _t->on_resetName_clicked(); break;
        case 3: _t->on_sortType_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_cancelResourceListFilter_clicked(); break;
        case 5: _t->on_resourceListFilter_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->resource_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 7: _t->resourceUsage_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 8: _t->on_viewContents_clicked(); break;
        case 9: _t->on_resourceUsage_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 10: _t->resourceUsage_SplitByMarker_toggled(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ResourceInspector::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_ResourceInspector.data,
    qt_meta_data_ResourceInspector,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ResourceInspector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourceInspector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ResourceInspector.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IResourceInspector"))
        return static_cast< IResourceInspector*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QFrame::qt_metacast(_clname);
}

int ResourceInspector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
