/****************************************************************************
** Meta object code from reading C++ file 'RDTextEdit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/Extended/RDTextEdit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RDTextEdit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RDTextEditDropDownButton_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTextEditDropDownButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTextEditDropDownButton_t qt_meta_stringdata_RDTextEditDropDownButton = {
    {
QT_MOC_LITERAL(0, 0, 24) // "RDTextEditDropDownButton"

    },
    "RDTextEditDropDownButton"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTextEditDropDownButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void RDTextEditDropDownButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RDTextEditDropDownButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QToolButton::staticMetaObject>(),
    qt_meta_stringdata_RDTextEditDropDownButton.data,
    qt_meta_data_RDTextEditDropDownButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTextEditDropDownButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTextEditDropDownButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTextEditDropDownButton.stringdata0))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int RDTextEditDropDownButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_RDTextEdit_t {
    QByteArrayData data[16];
    char stringdata0[151];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTextEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTextEdit_t qt_meta_stringdata_RDTextEdit = {
    {
QT_MOC_LITERAL(0, 0, 10), // "RDTextEdit"
QT_MOC_LITERAL(1, 11, 5), // "enter"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 5), // "leave"
QT_MOC_LITERAL(4, 24, 10), // "hoverEnter"
QT_MOC_LITERAL(5, 35, 10), // "hoverLeave"
QT_MOC_LITERAL(6, 46, 15), // "dropDownClicked"
QT_MOC_LITERAL(7, 62, 10), // "mouseMoved"
QT_MOC_LITERAL(8, 73, 12), // "QMouseEvent*"
QT_MOC_LITERAL(9, 86, 5), // "event"
QT_MOC_LITERAL(10, 92, 8), // "keyPress"
QT_MOC_LITERAL(11, 101, 10), // "QKeyEvent*"
QT_MOC_LITERAL(12, 112, 1), // "e"
QT_MOC_LITERAL(13, 114, 15), // "completionBegin"
QT_MOC_LITERAL(14, 130, 6), // "prefix"
QT_MOC_LITERAL(15, 137, 13) // "completionEnd"

    },
    "RDTextEdit\0enter\0\0leave\0hoverEnter\0"
    "hoverLeave\0dropDownClicked\0mouseMoved\0"
    "QMouseEvent*\0event\0keyPress\0QKeyEvent*\0"
    "e\0completionBegin\0prefix\0completionEnd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTextEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    0,   62,    2, 0x06 /* Public */,
       6,    0,   63,    2, 0x06 /* Public */,
       7,    1,   64,    2, 0x06 /* Public */,
      10,    1,   67,    2, 0x06 /* Public */,
      13,    1,   70,    2, 0x06 /* Public */,
      15,    0,   73,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void,

       0        // eod
};

void RDTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RDTextEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enter(); break;
        case 1: _t->leave(); break;
        case 2: _t->hoverEnter(); break;
        case 3: _t->hoverLeave(); break;
        case 4: _t->dropDownClicked(); break;
        case 5: _t->mouseMoved((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 6: _t->keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 7: _t->completionBegin((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 8: _t->completionEnd(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::enter)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::leave)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::hoverEnter)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::hoverLeave)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::dropDownClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)(QMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::mouseMoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)(QKeyEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::keyPress)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::completionBegin)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (RDTextEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTextEdit::completionEnd)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject RDTextEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextEdit::staticMetaObject>(),
    qt_meta_stringdata_RDTextEdit.data,
    qt_meta_data_RDTextEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTextEdit.stringdata0))
        return static_cast<void*>(this);
    return QTextEdit::qt_metacast(_clname);
}

int RDTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void RDTextEdit::enter()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RDTextEdit::leave()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RDTextEdit::hoverEnter()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RDTextEdit::hoverLeave()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RDTextEdit::dropDownClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RDTextEdit::mouseMoved(QMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void RDTextEdit::keyPress(QKeyEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void RDTextEdit::completionBegin(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void RDTextEdit::completionEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
