/****************************************************************************
** Meta object code from reading C++ file 'FindReplace.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/FindReplace.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FindReplace.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FindReplace_t {
    QByteArrayData data[24];
    char stringdata0[328];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FindReplace_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FindReplace_t qt_meta_stringdata_FindReplace = {
    {
QT_MOC_LITERAL(0, 0, 11), // "FindReplace"
QT_MOC_LITERAL(1, 12, 11), // "performFind"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 14), // "performFindAll"
QT_MOC_LITERAL(4, 40, 14), // "performReplace"
QT_MOC_LITERAL(5, 55, 17), // "performReplaceAll"
QT_MOC_LITERAL(6, 73, 8), // "keyPress"
QT_MOC_LITERAL(7, 82, 10), // "QKeyEvent*"
QT_MOC_LITERAL(8, 93, 1), // "e"
QT_MOC_LITERAL(9, 95, 19), // "allowUserModeChange"
QT_MOC_LITERAL(10, 115, 5), // "allow"
QT_MOC_LITERAL(11, 121, 14), // "setReplaceMode"
QT_MOC_LITERAL(12, 136, 9), // "replacing"
QT_MOC_LITERAL(13, 146, 12), // "setDirection"
QT_MOC_LITERAL(14, 159, 15), // "SearchDirection"
QT_MOC_LITERAL(15, 175, 3), // "dir"
QT_MOC_LITERAL(16, 179, 9), // "takeFocus"
QT_MOC_LITERAL(17, 189, 19), // "on_findPrev_clicked"
QT_MOC_LITERAL(18, 209, 15), // "on_find_clicked"
QT_MOC_LITERAL(19, 225, 18), // "on_findAll_clicked"
QT_MOC_LITERAL(20, 244, 18), // "on_replace_clicked"
QT_MOC_LITERAL(21, 263, 21), // "on_replaceAll_clicked"
QT_MOC_LITERAL(22, 285, 19), // "on_findMode_clicked"
QT_MOC_LITERAL(23, 305, 22) // "on_replaceMode_clicked"

    },
    "FindReplace\0performFind\0\0performFindAll\0"
    "performReplace\0performReplaceAll\0"
    "keyPress\0QKeyEvent*\0e\0allowUserModeChange\0"
    "allow\0setReplaceMode\0replacing\0"
    "setDirection\0SearchDirection\0dir\0"
    "takeFocus\0on_findPrev_clicked\0"
    "on_find_clicked\0on_findAll_clicked\0"
    "on_replace_clicked\0on_replaceAll_clicked\0"
    "on_findMode_clicked\0on_replaceMode_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FindReplace[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    0,   95,    2, 0x06 /* Public */,
       4,    0,   96,    2, 0x06 /* Public */,
       5,    0,   97,    2, 0x06 /* Public */,
       6,    1,   98,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  101,    2, 0x0a /* Public */,
      11,    1,  104,    2, 0x0a /* Public */,
      13,    1,  107,    2, 0x0a /* Public */,
      16,    0,  110,    2, 0x0a /* Public */,
      17,    0,  111,    2, 0x08 /* Private */,
      18,    0,  112,    2, 0x08 /* Private */,
      19,    0,  113,    2, 0x08 /* Private */,
      20,    0,  114,    2, 0x08 /* Private */,
      21,    0,  115,    2, 0x08 /* Private */,
      22,    0,  116,    2, 0x08 /* Private */,
      23,    0,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void FindReplace::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FindReplace *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->performFind(); break;
        case 1: _t->performFindAll(); break;
        case 2: _t->performReplace(); break;
        case 3: _t->performReplaceAll(); break;
        case 4: _t->keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 5: _t->allowUserModeChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setReplaceMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setDirection((*reinterpret_cast< SearchDirection(*)>(_a[1]))); break;
        case 8: _t->takeFocus(); break;
        case 9: _t->on_findPrev_clicked(); break;
        case 10: _t->on_find_clicked(); break;
        case 11: _t->on_findAll_clicked(); break;
        case 12: _t->on_replace_clicked(); break;
        case 13: _t->on_replaceAll_clicked(); break;
        case 14: _t->on_findMode_clicked(); break;
        case 15: _t->on_replaceMode_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (FindReplace::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FindReplace::performFind)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (FindReplace::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FindReplace::performFindAll)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (FindReplace::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FindReplace::performReplace)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (FindReplace::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FindReplace::performReplaceAll)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (FindReplace::*)(QKeyEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FindReplace::keyPress)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject FindReplace::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_FindReplace.data,
    qt_meta_data_FindReplace,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FindReplace::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FindReplace::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FindReplace.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int FindReplace::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void FindReplace::performFind()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FindReplace::performFindAll()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FindReplace::performReplace()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FindReplace::performReplaceAll()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FindReplace::keyPress(QKeyEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
