/****************************************************************************
** Meta object code from reading C++ file 'BufferFormatSpecifier.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/BufferFormatSpecifier.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BufferFormatSpecifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferFormatList_t {
    QByteArrayData data[3];
    char stringdata0[36];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferFormatList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferFormatList_t qt_meta_stringdata_BufferFormatList = {
    {
QT_MOC_LITERAL(0, 0, 16), // "BufferFormatList"
QT_MOC_LITERAL(1, 17, 17), // "formatListUpdated"
QT_MOC_LITERAL(2, 35, 0) // ""

    },
    "BufferFormatList\0formatListUpdated\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferFormatList[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void BufferFormatList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferFormatList *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->formatListUpdated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferFormatList::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferFormatList::formatListUpdated)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject BufferFormatList::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_BufferFormatList.data,
    qt_meta_data_BufferFormatList,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferFormatList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferFormatList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferFormatList.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BufferFormatList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void BufferFormatList::formatListUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_BufferFormatSpecifier_t {
    QByteArrayData data[21];
    char stringdata0[325];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferFormatSpecifier_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferFormatSpecifier_t qt_meta_stringdata_BufferFormatSpecifier = {
    {
QT_MOC_LITERAL(0, 0, 21), // "BufferFormatSpecifier"
QT_MOC_LITERAL(1, 22, 13), // "processFormat"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 6), // "format"
QT_MOC_LITERAL(4, 44, 19), // "on_showHelp_toggled"
QT_MOC_LITERAL(5, 64, 4), // "help"
QT_MOC_LITERAL(6, 69, 18), // "on_loadDef_clicked"
QT_MOC_LITERAL(7, 88, 18), // "on_saveDef_clicked"
QT_MOC_LITERAL(8, 107, 17), // "on_delDef_clicked"
QT_MOC_LITERAL(9, 125, 21), // "on_savedList_keyPress"
QT_MOC_LITERAL(10, 147, 10), // "QKeyEvent*"
QT_MOC_LITERAL(11, 158, 5), // "event"
QT_MOC_LITERAL(12, 164, 24), // "on_savedList_itemChanged"
QT_MOC_LITERAL(13, 189, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(14, 207, 4), // "item"
QT_MOC_LITERAL(15, 212, 6), // "column"
QT_MOC_LITERAL(16, 219, 30), // "on_savedList_itemDoubleClicked"
QT_MOC_LITERAL(17, 250, 33), // "on_savedList_itemSelectionCha..."
QT_MOC_LITERAL(18, 284, 9), // "setFormat"
QT_MOC_LITERAL(19, 294, 16), // "updateFormatList"
QT_MOC_LITERAL(20, 311, 13) // "apply_clicked"

    },
    "BufferFormatSpecifier\0processFormat\0"
    "\0format\0on_showHelp_toggled\0help\0"
    "on_loadDef_clicked\0on_saveDef_clicked\0"
    "on_delDef_clicked\0on_savedList_keyPress\0"
    "QKeyEvent*\0event\0on_savedList_itemChanged\0"
    "RDTreeWidgetItem*\0item\0column\0"
    "on_savedList_itemDoubleClicked\0"
    "on_savedList_itemSelectionChanged\0"
    "setFormat\0updateFormatList\0apply_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferFormatSpecifier[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   77,    2, 0x0a /* Public */,
       6,    0,   80,    2, 0x0a /* Public */,
       7,    0,   81,    2, 0x0a /* Public */,
       8,    0,   82,    2, 0x0a /* Public */,
       9,    1,   83,    2, 0x0a /* Public */,
      12,    2,   86,    2, 0x0a /* Public */,
      16,    2,   91,    2, 0x0a /* Public */,
      17,    0,   96,    2, 0x0a /* Public */,
      18,    1,   97,    2, 0x0a /* Public */,
      19,    0,  100,    2, 0x0a /* Public */,
      20,    0,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,   15,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,   15,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void BufferFormatSpecifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferFormatSpecifier *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->processFormat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->on_showHelp_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->on_loadDef_clicked(); break;
        case 3: _t->on_saveDef_clicked(); break;
        case 4: _t->on_delDef_clicked(); break;
        case 5: _t->on_savedList_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 6: _t->on_savedList_itemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->on_savedList_itemDoubleClicked((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->on_savedList_itemSelectionChanged(); break;
        case 9: _t->setFormat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->updateFormatList(); break;
        case 11: _t->apply_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferFormatSpecifier::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferFormatSpecifier::processFormat)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferFormatSpecifier::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_BufferFormatSpecifier.data,
    qt_meta_data_BufferFormatSpecifier,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferFormatSpecifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferFormatSpecifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferFormatSpecifier.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int BufferFormatSpecifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void BufferFormatSpecifier::processFormat(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
