/****************************************************************************
** Meta object code from reading C++ file 'LogView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/LogView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'LogView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LogView_t {
    QByteArrayData data[17];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LogView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LogView_t qt_meta_stringdata_LogView = {
    {
QT_MOC_LITERAL(0, 0, 7), // "LogView"
QT_MOC_LITERAL(1, 8, 23), // "on_openExternal_clicked"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 15), // "on_save_clicked"
QT_MOC_LITERAL(4, 49, 25), // "on_textFilter_textChanged"
QT_MOC_LITERAL(5, 75, 4), // "text"
QT_MOC_LITERAL(6, 80, 40), // "on_textFilterMeaning_currentI..."
QT_MOC_LITERAL(7, 121, 5), // "index"
QT_MOC_LITERAL(8, 127, 23), // "on_regexpFilter_toggled"
QT_MOC_LITERAL(9, 151, 16), // "messages_refresh"
QT_MOC_LITERAL(10, 168, 17), // "messages_keyPress"
QT_MOC_LITERAL(11, 186, 10), // "QKeyEvent*"
QT_MOC_LITERAL(12, 197, 5), // "event"
QT_MOC_LITERAL(13, 203, 17), // "pidFilter_changed"
QT_MOC_LITERAL(14, 221, 14), // "QStandardItem*"
QT_MOC_LITERAL(15, 236, 4), // "item"
QT_MOC_LITERAL(16, 241, 18) // "typeFilter_changed"

    },
    "LogView\0on_openExternal_clicked\0\0"
    "on_save_clicked\0on_textFilter_textChanged\0"
    "text\0on_textFilterMeaning_currentIndexChanged\0"
    "index\0on_regexpFilter_toggled\0"
    "messages_refresh\0messages_keyPress\0"
    "QKeyEvent*\0event\0pidFilter_changed\0"
    "QStandardItem*\0item\0typeFilter_changed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LogView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x08 /* Private */,
       3,    0,   60,    2, 0x08 /* Private */,
       4,    1,   61,    2, 0x08 /* Private */,
       6,    1,   64,    2, 0x08 /* Private */,
       8,    0,   67,    2, 0x08 /* Private */,
       9,    0,   68,    2, 0x08 /* Private */,
      10,    1,   69,    2, 0x08 /* Private */,
      13,    1,   72,    2, 0x08 /* Private */,
      16,    1,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 14,   15,

       0        // eod
};

void LogView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LogView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_openExternal_clicked(); break;
        case 1: _t->on_save_clicked(); break;
        case 2: _t->on_textFilter_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->on_textFilterMeaning_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_regexpFilter_toggled(); break;
        case 5: _t->messages_refresh(); break;
        case 6: _t->messages_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 7: _t->pidFilter_changed((*reinterpret_cast< QStandardItem*(*)>(_a[1]))); break;
        case 8: _t->typeFilter_changed((*reinterpret_cast< QStandardItem*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject LogView::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_LogView.data,
    qt_meta_data_LogView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LogView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LogView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LogView.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IDiagnosticLogView"))
        return static_cast< IDiagnosticLogView*>(this);
    return QFrame::qt_metacast(_clname);
}

int LogView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
