/****************************************************************************
** Meta object code from reading C++ file 'CaptureDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/CaptureDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CaptureDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CaptureDialog_t {
    QByteArrayData data[24];
    char stringdata0[461];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CaptureDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CaptureDialog_t qt_meta_stringdata_CaptureDialog = {
    {
QT_MOC_LITERAL(0, 0, 13), // "CaptureDialog"
QT_MOC_LITERAL(1, 14, 15), // "checkAllowClose"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 24), // "on_exePathBrowse_clicked"
QT_MOC_LITERAL(4, 56, 22), // "on_exePath_textChanged"
QT_MOC_LITERAL(5, 79, 4), // "arg1"
QT_MOC_LITERAL(6, 84, 24), // "on_workDirBrowse_clicked"
QT_MOC_LITERAL(7, 109, 21), // "on_envVarEdit_clicked"
QT_MOC_LITERAL(8, 131, 28), // "on_processFilter_textChanged"
QT_MOC_LITERAL(9, 160, 24), // "on_processRefesh_clicked"
QT_MOC_LITERAL(10, 185, 24), // "on_processList_activated"
QT_MOC_LITERAL(11, 210, 11), // "QModelIndex"
QT_MOC_LITERAL(12, 222, 5), // "index"
QT_MOC_LITERAL(13, 228, 23), // "on_saveSettings_clicked"
QT_MOC_LITERAL(14, 252, 23), // "on_loadSettings_clicked"
QT_MOC_LITERAL(15, 276, 26), // "on_loadLastCapture_clicked"
QT_MOC_LITERAL(16, 303, 17), // "on_launch_clicked"
QT_MOC_LITERAL(17, 321, 23), // "on_toggleGlobal_clicked"
QT_MOC_LITERAL(18, 345, 28), // "on_CaptureCallstacks_toggled"
QT_MOC_LITERAL(19, 374, 7), // "checked"
QT_MOC_LITERAL(20, 382, 26), // "vulkanLayerWarn_mouseClick"
QT_MOC_LITERAL(21, 409, 22), // "androidWarn_mouseClick"
QT_MOC_LITERAL(22, 432, 17), // "lineEdit_keyPress"
QT_MOC_LITERAL(23, 450, 10) // "QKeyEvent*"

    },
    "CaptureDialog\0checkAllowClose\0\0"
    "on_exePathBrowse_clicked\0"
    "on_exePath_textChanged\0arg1\0"
    "on_workDirBrowse_clicked\0on_envVarEdit_clicked\0"
    "on_processFilter_textChanged\0"
    "on_processRefesh_clicked\0"
    "on_processList_activated\0QModelIndex\0"
    "index\0on_saveSettings_clicked\0"
    "on_loadSettings_clicked\0"
    "on_loadLastCapture_clicked\0on_launch_clicked\0"
    "on_toggleGlobal_clicked\0"
    "on_CaptureCallstacks_toggled\0checked\0"
    "vulkanLayerWarn_mouseClick\0"
    "androidWarn_mouseClick\0lineEdit_keyPress\0"
    "QKeyEvent*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CaptureDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    0,  100,    2, 0x08 /* Private */,
       4,    1,  101,    2, 0x08 /* Private */,
       6,    0,  104,    2, 0x08 /* Private */,
       7,    0,  105,    2, 0x08 /* Private */,
       8,    1,  106,    2, 0x08 /* Private */,
       9,    0,  109,    2, 0x08 /* Private */,
      10,    1,  110,    2, 0x08 /* Private */,
      13,    0,  113,    2, 0x08 /* Private */,
      14,    0,  114,    2, 0x08 /* Private */,
      15,    0,  115,    2, 0x08 /* Private */,
      16,    0,  116,    2, 0x08 /* Private */,
      17,    0,  117,    2, 0x08 /* Private */,
      18,    1,  118,    2, 0x08 /* Private */,
      20,    0,  121,    2, 0x08 /* Private */,
      21,    0,  122,    2, 0x08 /* Private */,
      22,    1,  123,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23,    2,

       0        // eod
};

void CaptureDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CaptureDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->checkAllowClose();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->on_exePathBrowse_clicked(); break;
        case 2: _t->on_exePath_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->on_workDirBrowse_clicked(); break;
        case 4: _t->on_envVarEdit_clicked(); break;
        case 5: _t->on_processFilter_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->on_processRefesh_clicked(); break;
        case 7: _t->on_processList_activated((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 8: _t->on_saveSettings_clicked(); break;
        case 9: _t->on_loadSettings_clicked(); break;
        case 10: _t->on_loadLastCapture_clicked(); break;
        case 11: _t->on_launch_clicked(); break;
        case 12: _t->on_toggleGlobal_clicked(); break;
        case 13: _t->on_CaptureCallstacks_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->vulkanLayerWarn_mouseClick(); break;
        case 15: _t->androidWarn_mouseClick(); break;
        case 16: _t->lineEdit_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CaptureDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_CaptureDialog.data,
    qt_meta_data_CaptureDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CaptureDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CaptureDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CaptureDialog.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ICaptureDialog"))
        return static_cast< ICaptureDialog*>(this);
    return QFrame::qt_metacast(_clname);
}

int CaptureDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
