/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/MainWindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NetworkWorker_t {
    QByteArrayData data[8];
    char stringdata0[70];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkWorker_t qt_meta_stringdata_NetworkWorker = {
    {
QT_MOC_LITERAL(0, 0, 13), // "NetworkWorker"
QT_MOC_LITERAL(1, 14, 13), // "requestFailed"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 3), // "url"
QT_MOC_LITERAL(4, 33, 5), // "error"
QT_MOC_LITERAL(5, 39, 16), // "requestCompleted"
QT_MOC_LITERAL(6, 56, 9), // "replyData"
QT_MOC_LITERAL(7, 66, 3) // "get"

    },
    "NetworkWorker\0requestFailed\0\0url\0error\0"
    "requestCompleted\0replyData\0get"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkWorker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,
       5,    2,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   39,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QByteArray,    3,    6,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    3,

       0        // eod
};

void NetworkWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkWorker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestFailed((*reinterpret_cast< QUrl(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 1: _t->requestCompleted((*reinterpret_cast< QUrl(*)>(_a[1])),(*reinterpret_cast< QByteArray(*)>(_a[2]))); break;
        case 2: _t->get((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (NetworkWorker::*)(QUrl , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkWorker::requestFailed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (NetworkWorker::*)(QUrl , QByteArray );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkWorker::requestCompleted)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NetworkWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_NetworkWorker.data,
    qt_meta_data_NetworkWorker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int NetworkWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void NetworkWorker::requestFailed(QUrl _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void NetworkWorker::requestCompleted(QUrl _t1, QByteArray _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[61];
    char stringdata0[1798];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 17), // "networkRequestGet"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 3), // "url"
QT_MOC_LITERAL(4, 34, 24), // "on_action_Exit_triggered"
QT_MOC_LITERAL(5, 59, 25), // "on_action_About_triggered"
QT_MOC_LITERAL(6, 85, 32), // "on_action_Open_Capture_triggered"
QT_MOC_LITERAL(7, 118, 45), // "on_action_Open_Capture_with_O..."
QT_MOC_LITERAL(8, 164, 40), // "on_action_Save_Capture_Inplac..."
QT_MOC_LITERAL(9, 205, 35), // "on_action_Save_Capture_As_tri..."
QT_MOC_LITERAL(10, 241, 33), // "on_action_Close_Capture_trigg..."
QT_MOC_LITERAL(11, 275, 31), // "on_action_Mesh_Output_triggered"
QT_MOC_LITERAL(12, 307, 33), // "on_action_API_Inspector_trigg..."
QT_MOC_LITERAL(13, 341, 37), // "on_action_Annotation_Viewer_t..."
QT_MOC_LITERAL(14, 379, 33), // "on_action_Event_Browser_trigg..."
QT_MOC_LITERAL(15, 413, 34), // "on_action_Texture_Viewer_trig..."
QT_MOC_LITERAL(16, 448, 34), // "on_action_Pipeline_State_trig..."
QT_MOC_LITERAL(17, 483, 38), // "on_action_Launch_Application_..."
QT_MOC_LITERAL(18, 522, 39), // "on_action_Errors_and_Warnings..."
QT_MOC_LITERAL(19, 562, 28), // "on_action_Comments_triggered"
QT_MOC_LITERAL(20, 591, 37), // "on_action_Statistics_Viewer_t..."
QT_MOC_LITERAL(21, 629, 28), // "on_action_Timeline_triggered"
QT_MOC_LITERAL(22, 658, 32), // "on_action_Python_Shell_triggered"
QT_MOC_LITERAL(23, 691, 39), // "on_action_Inject_into_Process..."
QT_MOC_LITERAL(24, 731, 35), // "on_action_Resolve_Symbols_tri..."
QT_MOC_LITERAL(25, 767, 38), // "on_action_Recompress_Capture_..."
QT_MOC_LITERAL(26, 806, 38), // "on_action_EmbedExternalFiles_..."
QT_MOC_LITERAL(27, 845, 39), // "on_action_RemoveExternalFiles..."
QT_MOC_LITERAL(28, 885, 37), // "on_action_Start_Replay_Loop_t..."
QT_MOC_LITERAL(29, 923, 36), // "on_action_Open_RGP_Profile_tr..."
QT_MOC_LITERAL(30, 960, 38), // "on_action_Create_RGP_Profile_..."
QT_MOC_LITERAL(31, 999, 46), // "on_action_Attach_to_Running_I..."
QT_MOC_LITERAL(32, 1046, 37), // "on_action_Manage_Extensions_t..."
QT_MOC_LITERAL(33, 1084, 41), // "on_action_Manage_Remote_Serve..."
QT_MOC_LITERAL(34, 1126, 28), // "on_action_Settings_triggered"
QT_MOC_LITERAL(35, 1155, 38), // "on_action_View_Documentation_..."
QT_MOC_LITERAL(36, 1194, 36), // "on_action_Source_on_GitHub_tr..."
QT_MOC_LITERAL(37, 1231, 43), // "on_action_Build_Release_Downl..."
QT_MOC_LITERAL(38, 1275, 29), // "on_action_Show_Tips_triggered"
QT_MOC_LITERAL(39, 1305, 34), // "on_action_Counter_Viewer_trig..."
QT_MOC_LITERAL(40, 1340, 38), // "on_action_Resource_Inspector_..."
QT_MOC_LITERAL(41, 1379, 37), // "on_action_Send_Error_Report_t..."
QT_MOC_LITERAL(42, 1417, 37), // "on_action_Check_for_Updates_t..."
QT_MOC_LITERAL(43, 1455, 39), // "on_action_Clear_Reported_Bugs..."
QT_MOC_LITERAL(44, 1495, 20), // "saveLayout_triggered"
QT_MOC_LITERAL(45, 1516, 20), // "loadLayout_triggered"
QT_MOC_LITERAL(46, 1537, 25), // "updateAvailable_triggered"
QT_MOC_LITERAL(47, 1563, 12), // "messageCheck"
QT_MOC_LITERAL(48, 1576, 11), // "remoteProbe"
QT_MOC_LITERAL(49, 1588, 19), // "statusDoubleClicked"
QT_MOC_LITERAL(50, 1608, 12), // "QMouseEvent*"
QT_MOC_LITERAL(51, 1621, 5), // "event"
QT_MOC_LITERAL(52, 1627, 13), // "switchContext"
QT_MOC_LITERAL(53, 1641, 26), // "contextChooser_menuShowing"
QT_MOC_LITERAL(54, 1668, 22), // "updateToolsMenuOptions"
QT_MOC_LITERAL(55, 1691, 23), // "ClearRecentCaptureFiles"
QT_MOC_LITERAL(56, 1715, 26), // "ClearRecentCaptureSettings"
QT_MOC_LITERAL(57, 1742, 20), // "networkRequestFailed"
QT_MOC_LITERAL(58, 1763, 5), // "error"
QT_MOC_LITERAL(59, 1769, 23), // "networkRequestCompleted"
QT_MOC_LITERAL(60, 1793, 4) // "data"

    },
    "MainWindow\0networkRequestGet\0\0url\0"
    "on_action_Exit_triggered\0"
    "on_action_About_triggered\0"
    "on_action_Open_Capture_triggered\0"
    "on_action_Open_Capture_with_Options_triggered\0"
    "on_action_Save_Capture_Inplace_triggered\0"
    "on_action_Save_Capture_As_triggered\0"
    "on_action_Close_Capture_triggered\0"
    "on_action_Mesh_Output_triggered\0"
    "on_action_API_Inspector_triggered\0"
    "on_action_Annotation_Viewer_triggered\0"
    "on_action_Event_Browser_triggered\0"
    "on_action_Texture_Viewer_triggered\0"
    "on_action_Pipeline_State_triggered\0"
    "on_action_Launch_Application_triggered\0"
    "on_action_Errors_and_Warnings_triggered\0"
    "on_action_Comments_triggered\0"
    "on_action_Statistics_Viewer_triggered\0"
    "on_action_Timeline_triggered\0"
    "on_action_Python_Shell_triggered\0"
    "on_action_Inject_into_Process_triggered\0"
    "on_action_Resolve_Symbols_triggered\0"
    "on_action_Recompress_Capture_triggered\0"
    "on_action_EmbedExternalFiles_triggered\0"
    "on_action_RemoveExternalFiles_triggered\0"
    "on_action_Start_Replay_Loop_triggered\0"
    "on_action_Open_RGP_Profile_triggered\0"
    "on_action_Create_RGP_Profile_triggered\0"
    "on_action_Attach_to_Running_Instance_triggered\0"
    "on_action_Manage_Extensions_triggered\0"
    "on_action_Manage_Remote_Servers_triggered\0"
    "on_action_Settings_triggered\0"
    "on_action_View_Documentation_triggered\0"
    "on_action_Source_on_GitHub_triggered\0"
    "on_action_Build_Release_Downloads_triggered\0"
    "on_action_Show_Tips_triggered\0"
    "on_action_Counter_Viewer_triggered\0"
    "on_action_Resource_Inspector_triggered\0"
    "on_action_Send_Error_Report_triggered\0"
    "on_action_Check_for_Updates_triggered\0"
    "on_action_Clear_Reported_Bugs_triggered\0"
    "saveLayout_triggered\0loadLayout_triggered\0"
    "updateAvailable_triggered\0messageCheck\0"
    "remoteProbe\0statusDoubleClicked\0"
    "QMouseEvent*\0event\0switchContext\0"
    "contextChooser_menuShowing\0"
    "updateToolsMenuOptions\0ClearRecentCaptureFiles\0"
    "ClearRecentCaptureSettings\0"
    "networkRequestFailed\0error\0"
    "networkRequestCompleted\0data"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      54,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  284,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  287,    2, 0x08 /* Private */,
       5,    0,  288,    2, 0x08 /* Private */,
       6,    0,  289,    2, 0x08 /* Private */,
       7,    0,  290,    2, 0x08 /* Private */,
       8,    0,  291,    2, 0x08 /* Private */,
       9,    0,  292,    2, 0x08 /* Private */,
      10,    0,  293,    2, 0x08 /* Private */,
      11,    0,  294,    2, 0x08 /* Private */,
      12,    0,  295,    2, 0x08 /* Private */,
      13,    0,  296,    2, 0x08 /* Private */,
      14,    0,  297,    2, 0x08 /* Private */,
      15,    0,  298,    2, 0x08 /* Private */,
      16,    0,  299,    2, 0x08 /* Private */,
      17,    0,  300,    2, 0x08 /* Private */,
      18,    0,  301,    2, 0x08 /* Private */,
      19,    0,  302,    2, 0x08 /* Private */,
      20,    0,  303,    2, 0x08 /* Private */,
      21,    0,  304,    2, 0x08 /* Private */,
      22,    0,  305,    2, 0x08 /* Private */,
      23,    0,  306,    2, 0x08 /* Private */,
      24,    0,  307,    2, 0x08 /* Private */,
      25,    0,  308,    2, 0x08 /* Private */,
      26,    0,  309,    2, 0x08 /* Private */,
      27,    0,  310,    2, 0x08 /* Private */,
      28,    0,  311,    2, 0x08 /* Private */,
      29,    0,  312,    2, 0x08 /* Private */,
      30,    0,  313,    2, 0x08 /* Private */,
      31,    0,  314,    2, 0x08 /* Private */,
      32,    0,  315,    2, 0x08 /* Private */,
      33,    0,  316,    2, 0x08 /* Private */,
      34,    0,  317,    2, 0x08 /* Private */,
      35,    0,  318,    2, 0x08 /* Private */,
      36,    0,  319,    2, 0x08 /* Private */,
      37,    0,  320,    2, 0x08 /* Private */,
      38,    0,  321,    2, 0x08 /* Private */,
      39,    0,  322,    2, 0x08 /* Private */,
      40,    0,  323,    2, 0x08 /* Private */,
      41,    0,  324,    2, 0x08 /* Private */,
      42,    0,  325,    2, 0x08 /* Private */,
      43,    0,  326,    2, 0x08 /* Private */,
      44,    0,  327,    2, 0x08 /* Private */,
      45,    0,  328,    2, 0x08 /* Private */,
      46,    0,  329,    2, 0x08 /* Private */,
      47,    0,  330,    2, 0x08 /* Private */,
      48,    0,  331,    2, 0x08 /* Private */,
      49,    1,  332,    2, 0x08 /* Private */,
      52,    0,  335,    2, 0x08 /* Private */,
      53,    0,  336,    2, 0x08 /* Private */,
      54,    0,  337,    2, 0x08 /* Private */,
      55,    0,  338,    2, 0x08 /* Private */,
      56,    0,  339,    2, 0x08 /* Private */,
      57,    2,  340,    2, 0x08 /* Private */,
      59,    2,  345,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 50,   51,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString,    3,   58,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QByteArray,    3,   60,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->networkRequestGet((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 1: _t->on_action_Exit_triggered(); break;
        case 2: _t->on_action_About_triggered(); break;
        case 3: _t->on_action_Open_Capture_triggered(); break;
        case 4: _t->on_action_Open_Capture_with_Options_triggered(); break;
        case 5: _t->on_action_Save_Capture_Inplace_triggered(); break;
        case 6: _t->on_action_Save_Capture_As_triggered(); break;
        case 7: _t->on_action_Close_Capture_triggered(); break;
        case 8: _t->on_action_Mesh_Output_triggered(); break;
        case 9: _t->on_action_API_Inspector_triggered(); break;
        case 10: _t->on_action_Annotation_Viewer_triggered(); break;
        case 11: _t->on_action_Event_Browser_triggered(); break;
        case 12: _t->on_action_Texture_Viewer_triggered(); break;
        case 13: _t->on_action_Pipeline_State_triggered(); break;
        case 14: _t->on_action_Launch_Application_triggered(); break;
        case 15: _t->on_action_Errors_and_Warnings_triggered(); break;
        case 16: _t->on_action_Comments_triggered(); break;
        case 17: _t->on_action_Statistics_Viewer_triggered(); break;
        case 18: _t->on_action_Timeline_triggered(); break;
        case 19: _t->on_action_Python_Shell_triggered(); break;
        case 20: _t->on_action_Inject_into_Process_triggered(); break;
        case 21: _t->on_action_Resolve_Symbols_triggered(); break;
        case 22: _t->on_action_Recompress_Capture_triggered(); break;
        case 23: _t->on_action_EmbedExternalFiles_triggered(); break;
        case 24: _t->on_action_RemoveExternalFiles_triggered(); break;
        case 25: _t->on_action_Start_Replay_Loop_triggered(); break;
        case 26: _t->on_action_Open_RGP_Profile_triggered(); break;
        case 27: _t->on_action_Create_RGP_Profile_triggered(); break;
        case 28: _t->on_action_Attach_to_Running_Instance_triggered(); break;
        case 29: _t->on_action_Manage_Extensions_triggered(); break;
        case 30: _t->on_action_Manage_Remote_Servers_triggered(); break;
        case 31: _t->on_action_Settings_triggered(); break;
        case 32: _t->on_action_View_Documentation_triggered(); break;
        case 33: _t->on_action_Source_on_GitHub_triggered(); break;
        case 34: _t->on_action_Build_Release_Downloads_triggered(); break;
        case 35: _t->on_action_Show_Tips_triggered(); break;
        case 36: _t->on_action_Counter_Viewer_triggered(); break;
        case 37: _t->on_action_Resource_Inspector_triggered(); break;
        case 38: _t->on_action_Send_Error_Report_triggered(); break;
        case 39: _t->on_action_Check_for_Updates_triggered(); break;
        case 40: _t->on_action_Clear_Reported_Bugs_triggered(); break;
        case 41: _t->saveLayout_triggered(); break;
        case 42: _t->loadLayout_triggered(); break;
        case 43: _t->updateAvailable_triggered(); break;
        case 44: _t->messageCheck(); break;
        case 45: _t->remoteProbe(); break;
        case 46: _t->statusDoubleClicked((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 47: _t->switchContext(); break;
        case 48: _t->contextChooser_menuShowing(); break;
        case 49: _t->updateToolsMenuOptions(); break;
        case 50: _t->ClearRecentCaptureFiles(); break;
        case 51: _t->ClearRecentCaptureSettings(); break;
        case 52: _t->networkRequestFailed((*reinterpret_cast< QUrl(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 53: _t->networkRequestCompleted((*reinterpret_cast< QUrl(*)>(_a[1])),(*reinterpret_cast< QByteArray(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)(QUrl );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::networkRequestGet)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IMainWindow"))
        return static_cast< IMainWindow*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 54)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 54)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 54;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::networkRequestGet(QUrl _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
