/****************************************************************************
** Meta object code from reading C++ file 'SettingsDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/SettingsDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SettingsDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SettingsDialog_t {
    QByteArrayData data[69];
    char stringdata0[1799];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SettingsDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SettingsDialog_t qt_meta_stringdata_SettingsDialog = {
    {
QT_MOC_LITERAL(0, 0, 14), // "SettingsDialog"
QT_MOC_LITERAL(1, 15, 29), // "on_pages_itemSelectionChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 20), // "on_okButton_accepted"
QT_MOC_LITERAL(4, 67, 34), // "on_Font_Family_currentIndexCh..."
QT_MOC_LITERAL(5, 102, 5), // "index"
QT_MOC_LITERAL(6, 108, 38), // "on_Font_MonoFamily_currentInd..."
QT_MOC_LITERAL(7, 147, 39), // "on_Font_GlobalScale_currentIn..."
QT_MOC_LITERAL(8, 187, 30), // "Font_GlobalScale_returnPressed"
QT_MOC_LITERAL(9, 218, 30), // "on_UIStyle_currentIndexChanged"
QT_MOC_LITERAL(10, 249, 27), // "on_tempDirectory_textEdited"
QT_MOC_LITERAL(11, 277, 4), // "temp"
QT_MOC_LITERAL(12, 282, 27), // "on_saveDirectory_textEdited"
QT_MOC_LITERAL(13, 310, 4), // "save"
QT_MOC_LITERAL(14, 315, 37), // "on_browseSaveCaptureDirectory..."
QT_MOC_LITERAL(15, 353, 26), // "on_AllowGlobalHook_toggled"
QT_MOC_LITERAL(16, 380, 7), // "checked"
QT_MOC_LITERAL(17, 388, 29), // "on_AllowProcessInject_toggled"
QT_MOC_LITERAL(18, 418, 34), // "on_CheckUpdate_AllowChecks_to..."
QT_MOC_LITERAL(19, 453, 32), // "on_Font_PreferMonospaced_toggled"
QT_MOC_LITERAL(20, 486, 30), // "on_AlwaysReplayLocally_toggled"
QT_MOC_LITERAL(21, 517, 30), // "on_analyticsAutoSubmit_toggled"
QT_MOC_LITERAL(22, 548, 31), // "on_analyticsManualCheck_toggled"
QT_MOC_LITERAL(23, 580, 26), // "on_analyticsOptOut_toggled"
QT_MOC_LITERAL(24, 607, 23), // "on_configEditor_clicked"
QT_MOC_LITERAL(25, 631, 28), // "on_chooseSearchPaths_clicked"
QT_MOC_LITERAL(26, 660, 24), // "on_chooseIgnores_clicked"
QT_MOC_LITERAL(27, 685, 38), // "on_ExternalTool_RGPIntegratio..."
QT_MOC_LITERAL(28, 724, 44), // "on_ExternalTool_RadeonGPUProf..."
QT_MOC_LITERAL(29, 769, 3), // "rgp"
QT_MOC_LITERAL(30, 773, 24), // "on_browseRGPPath_clicked"
QT_MOC_LITERAL(31, 798, 39), // "on_TextureViewer_PerTexSettin..."
QT_MOC_LITERAL(32, 838, 35), // "on_TextureViewer_ResetRange_t..."
QT_MOC_LITERAL(33, 874, 36), // "on_TextureViewer_PerTexYFlip_..."
QT_MOC_LITERAL(34, 911, 48), // "on_TextureViewer_ChooseShader..."
QT_MOC_LITERAL(35, 960, 38), // "on_ShaderViewer_FriendlyNamin..."
QT_MOC_LITERAL(36, 999, 24), // "on_addShaderTool_clicked"
QT_MOC_LITERAL(37, 1024, 25), // "on_editShaderTool_clicked"
QT_MOC_LITERAL(38, 1050, 27), // "on_deleteShaderTool_clicked"
QT_MOC_LITERAL(39, 1078, 35), // "on_shaderTools_itemSelectionC..."
QT_MOC_LITERAL(40, 1114, 23), // "on_shaderTools_keyPress"
QT_MOC_LITERAL(41, 1138, 10), // "QKeyEvent*"
QT_MOC_LITERAL(42, 1149, 5), // "event"
QT_MOC_LITERAL(43, 1155, 32), // "on_shaderTools_itemDoubleClicked"
QT_MOC_LITERAL(44, 1188, 17), // "QTableWidgetItem*"
QT_MOC_LITERAL(45, 1206, 4), // "item"
QT_MOC_LITERAL(46, 1211, 20), // "shaderTools_rowMoved"
QT_MOC_LITERAL(47, 1232, 12), // "logicalIndex"
QT_MOC_LITERAL(48, 1245, 14), // "oldVisualIndex"
QT_MOC_LITERAL(49, 1260, 14), // "newVisualIndex"
QT_MOC_LITERAL(50, 1275, 44), // "on_EventBrowser_TimeUnit_curr..."
QT_MOC_LITERAL(51, 1320, 31), // "on_EventBrowser_AddFake_toggled"
QT_MOC_LITERAL(52, 1352, 35), // "on_EventBrowser_ApplyColors_t..."
QT_MOC_LITERAL(53, 1388, 37), // "on_EventBrowser_ColorEventRow..."
QT_MOC_LITERAL(54, 1426, 30), // "on_Comments_ShowOnLoad_toggled"
QT_MOC_LITERAL(55, 1457, 37), // "on_browseTempCaptureDirectory..."
QT_MOC_LITERAL(56, 1495, 31), // "on_browseAndroidSDKPath_clicked"
QT_MOC_LITERAL(57, 1527, 24), // "on_browseJDKPath_clicked"
QT_MOC_LITERAL(58, 1552, 41), // "on_Android_MaxConnectTimeout_..."
QT_MOC_LITERAL(59, 1594, 7), // "timeout"
QT_MOC_LITERAL(60, 1602, 29), // "on_Android_SDKPath_textEdited"
QT_MOC_LITERAL(61, 1632, 3), // "sdk"
QT_MOC_LITERAL(62, 1636, 29), // "on_Android_JDKPath_textEdited"
QT_MOC_LITERAL(63, 1666, 3), // "jdk"
QT_MOC_LITERAL(64, 1670, 22), // "formatter_valueChanged"
QT_MOC_LITERAL(65, 1693, 5), // "value"
QT_MOC_LITERAL(66, 1699, 54), // "on_Formatter_OffsetSizeDispla..."
QT_MOC_LITERAL(67, 1754, 39), // "on_analyticsDescribeLabel_lin..."
QT_MOC_LITERAL(68, 1794, 4) // "link"

    },
    "SettingsDialog\0on_pages_itemSelectionChanged\0"
    "\0on_okButton_accepted\0"
    "on_Font_Family_currentIndexChanged\0"
    "index\0on_Font_MonoFamily_currentIndexChanged\0"
    "on_Font_GlobalScale_currentIndexChanged\0"
    "Font_GlobalScale_returnPressed\0"
    "on_UIStyle_currentIndexChanged\0"
    "on_tempDirectory_textEdited\0temp\0"
    "on_saveDirectory_textEdited\0save\0"
    "on_browseSaveCaptureDirectory_clicked\0"
    "on_AllowGlobalHook_toggled\0checked\0"
    "on_AllowProcessInject_toggled\0"
    "on_CheckUpdate_AllowChecks_toggled\0"
    "on_Font_PreferMonospaced_toggled\0"
    "on_AlwaysReplayLocally_toggled\0"
    "on_analyticsAutoSubmit_toggled\0"
    "on_analyticsManualCheck_toggled\0"
    "on_analyticsOptOut_toggled\0"
    "on_configEditor_clicked\0"
    "on_chooseSearchPaths_clicked\0"
    "on_chooseIgnores_clicked\0"
    "on_ExternalTool_RGPIntegration_toggled\0"
    "on_ExternalTool_RadeonGPUProfiler_textEdited\0"
    "rgp\0on_browseRGPPath_clicked\0"
    "on_TextureViewer_PerTexSettings_toggled\0"
    "on_TextureViewer_ResetRange_toggled\0"
    "on_TextureViewer_PerTexYFlip_toggled\0"
    "on_TextureViewer_ChooseShaderDirectories_clicked\0"
    "on_ShaderViewer_FriendlyNaming_toggled\0"
    "on_addShaderTool_clicked\0"
    "on_editShaderTool_clicked\0"
    "on_deleteShaderTool_clicked\0"
    "on_shaderTools_itemSelectionChanged\0"
    "on_shaderTools_keyPress\0QKeyEvent*\0"
    "event\0on_shaderTools_itemDoubleClicked\0"
    "QTableWidgetItem*\0item\0shaderTools_rowMoved\0"
    "logicalIndex\0oldVisualIndex\0newVisualIndex\0"
    "on_EventBrowser_TimeUnit_currentIndexChanged\0"
    "on_EventBrowser_AddFake_toggled\0"
    "on_EventBrowser_ApplyColors_toggled\0"
    "on_EventBrowser_ColorEventRow_toggled\0"
    "on_Comments_ShowOnLoad_toggled\0"
    "on_browseTempCaptureDirectory_clicked\0"
    "on_browseAndroidSDKPath_clicked\0"
    "on_browseJDKPath_clicked\0"
    "on_Android_MaxConnectTimeout_valueChanged\0"
    "timeout\0on_Android_SDKPath_textEdited\0"
    "sdk\0on_Android_JDKPath_textEdited\0jdk\0"
    "formatter_valueChanged\0value\0"
    "on_Formatter_OffsetSizeDisplayMode_currentIndexChanged\0"
    "on_analyticsDescribeLabel_linkActivated\0"
    "link"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SettingsDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      50,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  264,    2, 0x08 /* Private */,
       3,    0,  265,    2, 0x08 /* Private */,
       4,    1,  266,    2, 0x08 /* Private */,
       6,    1,  269,    2, 0x08 /* Private */,
       7,    1,  272,    2, 0x08 /* Private */,
       8,    0,  275,    2, 0x08 /* Private */,
       9,    1,  276,    2, 0x08 /* Private */,
      10,    1,  279,    2, 0x08 /* Private */,
      12,    1,  282,    2, 0x08 /* Private */,
      14,    0,  285,    2, 0x08 /* Private */,
      15,    1,  286,    2, 0x08 /* Private */,
      17,    1,  289,    2, 0x08 /* Private */,
      18,    1,  292,    2, 0x08 /* Private */,
      19,    1,  295,    2, 0x08 /* Private */,
      20,    1,  298,    2, 0x08 /* Private */,
      21,    1,  301,    2, 0x08 /* Private */,
      22,    1,  304,    2, 0x08 /* Private */,
      23,    1,  307,    2, 0x08 /* Private */,
      24,    0,  310,    2, 0x08 /* Private */,
      25,    0,  311,    2, 0x08 /* Private */,
      26,    0,  312,    2, 0x08 /* Private */,
      27,    1,  313,    2, 0x08 /* Private */,
      28,    1,  316,    2, 0x08 /* Private */,
      30,    0,  319,    2, 0x08 /* Private */,
      31,    1,  320,    2, 0x08 /* Private */,
      32,    1,  323,    2, 0x08 /* Private */,
      33,    1,  326,    2, 0x08 /* Private */,
      34,    0,  329,    2, 0x08 /* Private */,
      35,    1,  330,    2, 0x08 /* Private */,
      36,    0,  333,    2, 0x08 /* Private */,
      37,    0,  334,    2, 0x08 /* Private */,
      38,    0,  335,    2, 0x08 /* Private */,
      39,    0,  336,    2, 0x08 /* Private */,
      40,    1,  337,    2, 0x08 /* Private */,
      43,    1,  340,    2, 0x08 /* Private */,
      46,    3,  343,    2, 0x08 /* Private */,
      50,    1,  350,    2, 0x08 /* Private */,
      51,    1,  353,    2, 0x08 /* Private */,
      52,    1,  356,    2, 0x08 /* Private */,
      53,    1,  359,    2, 0x08 /* Private */,
      54,    1,  362,    2, 0x08 /* Private */,
      55,    0,  365,    2, 0x08 /* Private */,
      56,    0,  366,    2, 0x08 /* Private */,
      57,    0,  367,    2, 0x08 /* Private */,
      58,    1,  368,    2, 0x08 /* Private */,
      60,    1,  371,    2, 0x08 /* Private */,
      62,    1,  374,    2, 0x08 /* Private */,
      64,    1,  377,    2, 0x08 /* Private */,
      66,    1,  380,    2, 0x08 /* Private */,
      67,    1,  383,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 41,   42,
    QMetaType::Void, 0x80000000 | 44,   45,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   47,   48,   49,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,   59,
    QMetaType::Void, QMetaType::QString,   61,
    QMetaType::Void, QMetaType::QString,   63,
    QMetaType::Void, QMetaType::Int,   65,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,   68,

       0        // eod
};

void SettingsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_pages_itemSelectionChanged(); break;
        case 1: _t->on_okButton_accepted(); break;
        case 2: _t->on_Font_Family_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_Font_MonoFamily_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_Font_GlobalScale_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->Font_GlobalScale_returnPressed(); break;
        case 6: _t->on_UIStyle_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_tempDirectory_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->on_saveDirectory_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->on_browseSaveCaptureDirectory_clicked(); break;
        case 10: _t->on_AllowGlobalHook_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->on_AllowProcessInject_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->on_CheckUpdate_AllowChecks_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->on_Font_PreferMonospaced_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->on_AlwaysReplayLocally_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->on_analyticsAutoSubmit_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->on_analyticsManualCheck_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->on_analyticsOptOut_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->on_configEditor_clicked(); break;
        case 19: _t->on_chooseSearchPaths_clicked(); break;
        case 20: _t->on_chooseIgnores_clicked(); break;
        case 21: _t->on_ExternalTool_RGPIntegration_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->on_ExternalTool_RadeonGPUProfiler_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->on_browseRGPPath_clicked(); break;
        case 24: _t->on_TextureViewer_PerTexSettings_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->on_TextureViewer_ResetRange_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->on_TextureViewer_PerTexYFlip_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->on_TextureViewer_ChooseShaderDirectories_clicked(); break;
        case 28: _t->on_ShaderViewer_FriendlyNaming_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->on_addShaderTool_clicked(); break;
        case 30: _t->on_editShaderTool_clicked(); break;
        case 31: _t->on_deleteShaderTool_clicked(); break;
        case 32: _t->on_shaderTools_itemSelectionChanged(); break;
        case 33: _t->on_shaderTools_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 34: _t->on_shaderTools_itemDoubleClicked((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 35: _t->shaderTools_rowMoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 36: _t->on_EventBrowser_TimeUnit_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->on_EventBrowser_AddFake_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->on_EventBrowser_ApplyColors_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->on_EventBrowser_ColorEventRow_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->on_Comments_ShowOnLoad_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->on_browseTempCaptureDirectory_clicked(); break;
        case 42: _t->on_browseAndroidSDKPath_clicked(); break;
        case 43: _t->on_browseJDKPath_clicked(); break;
        case 44: _t->on_Android_MaxConnectTimeout_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 45: _t->on_Android_SDKPath_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 46: _t->on_Android_JDKPath_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 47: _t->formatter_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->on_Formatter_OffsetSizeDisplayMode_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 49: _t->on_analyticsDescribeLabel_linkActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SettingsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_SettingsDialog.data,
    qt_meta_data_SettingsDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SettingsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SettingsDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int SettingsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 50)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 50)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 50;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
