/****************************************************************************
** Meta object code from reading C++ file 'ShaderViewer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/ShaderViewer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ShaderViewer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ShaderViewer_t {
    QByteArrayData data[43];
    char stringdata0[706];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ShaderViewer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ShaderViewer_t qt_meta_stringdata_ShaderViewer = {
    {
QT_MOC_LITERAL(0, 0, 12), // "ShaderViewer"
QT_MOC_LITERAL(1, 13, 22), // "on_findReplace_clicked"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 18), // "on_refresh_clicked"
QT_MOC_LITERAL(4, 56, 20), // "on_unrefresh_clicked"
QT_MOC_LITERAL(5, 77, 21), // "on_resetEdits_clicked"
QT_MOC_LITERAL(6, 99, 18), // "on_intView_clicked"
QT_MOC_LITERAL(7, 118, 20), // "on_floatView_clicked"
QT_MOC_LITERAL(8, 139, 22), // "on_debugToggle_clicked"
QT_MOC_LITERAL(9, 162, 20), // "on_toggleLog_clicked"
QT_MOC_LITERAL(10, 183, 31), // "on_resources_sortByStep_clicked"
QT_MOC_LITERAL(11, 215, 35), // "on_resources_sortByResource_c..."
QT_MOC_LITERAL(12, 251, 20), // "on_watch_itemChanged"
QT_MOC_LITERAL(13, 272, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(14, 290, 4), // "item"
QT_MOC_LITERAL(15, 295, 6), // "column"
QT_MOC_LITERAL(16, 302, 19), // "readonly_keyPressed"
QT_MOC_LITERAL(17, 322, 10), // "QKeyEvent*"
QT_MOC_LITERAL(18, 333, 5), // "event"
QT_MOC_LITERAL(19, 339, 19), // "editable_keyPressed"
QT_MOC_LITERAL(20, 359, 17), // "debug_contextMenu"
QT_MOC_LITERAL(21, 377, 3), // "pos"
QT_MOC_LITERAL(22, 381, 21), // "variables_contextMenu"
QT_MOC_LITERAL(23, 403, 29), // "accessedResources_contextMenu"
QT_MOC_LITERAL(24, 433, 26), // "disassembly_buttonReleased"
QT_MOC_LITERAL(25, 460, 12), // "QMouseEvent*"
QT_MOC_LITERAL(26, 473, 23), // "disassemble_typeChanged"
QT_MOC_LITERAL(27, 497, 5), // "index"
QT_MOC_LITERAL(28, 503, 14), // "watch_keyPress"
QT_MOC_LITERAL(29, 518, 11), // "performFind"
QT_MOC_LITERAL(30, 530, 14), // "performFindAll"
QT_MOC_LITERAL(31, 545, 18), // "resultsDoubleClick"
QT_MOC_LITERAL(32, 564, 8), // "position"
QT_MOC_LITERAL(33, 573, 4), // "line"
QT_MOC_LITERAL(34, 578, 14), // "performReplace"
QT_MOC_LITERAL(35, 593, 17), // "performReplaceAll"
QT_MOC_LITERAL(36, 611, 17), // "snippet_constants"
QT_MOC_LITERAL(37, 629, 16), // "snippet_samplers"
QT_MOC_LITERAL(38, 646, 17), // "snippet_resources"
QT_MOC_LITERAL(39, 664, 18), // "disasm_tooltipShow"
QT_MOC_LITERAL(40, 683, 1), // "x"
QT_MOC_LITERAL(41, 685, 1), // "y"
QT_MOC_LITERAL(42, 687, 18) // "disasm_tooltipHide"

    },
    "ShaderViewer\0on_findReplace_clicked\0"
    "\0on_refresh_clicked\0on_unrefresh_clicked\0"
    "on_resetEdits_clicked\0on_intView_clicked\0"
    "on_floatView_clicked\0on_debugToggle_clicked\0"
    "on_toggleLog_clicked\0"
    "on_resources_sortByStep_clicked\0"
    "on_resources_sortByResource_clicked\0"
    "on_watch_itemChanged\0RDTreeWidgetItem*\0"
    "item\0column\0readonly_keyPressed\0"
    "QKeyEvent*\0event\0editable_keyPressed\0"
    "debug_contextMenu\0pos\0variables_contextMenu\0"
    "accessedResources_contextMenu\0"
    "disassembly_buttonReleased\0QMouseEvent*\0"
    "disassemble_typeChanged\0index\0"
    "watch_keyPress\0performFind\0performFindAll\0"
    "resultsDoubleClick\0position\0line\0"
    "performReplace\0performReplaceAll\0"
    "snippet_constants\0snippet_samplers\0"
    "snippet_resources\0disasm_tooltipShow\0"
    "x\0y\0disasm_tooltipHide"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ShaderViewer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  159,    2, 0x08 /* Private */,
       3,    0,  160,    2, 0x08 /* Private */,
       4,    0,  161,    2, 0x08 /* Private */,
       5,    0,  162,    2, 0x08 /* Private */,
       6,    0,  163,    2, 0x08 /* Private */,
       7,    0,  164,    2, 0x08 /* Private */,
       8,    0,  165,    2, 0x08 /* Private */,
       9,    0,  166,    2, 0x08 /* Private */,
      10,    0,  167,    2, 0x08 /* Private */,
      11,    0,  168,    2, 0x08 /* Private */,
      12,    2,  169,    2, 0x08 /* Private */,
      16,    1,  174,    2, 0x08 /* Private */,
      19,    1,  177,    2, 0x08 /* Private */,
      20,    1,  180,    2, 0x08 /* Private */,
      22,    1,  183,    2, 0x08 /* Private */,
      23,    1,  186,    2, 0x08 /* Private */,
      24,    1,  189,    2, 0x08 /* Private */,
      26,    1,  192,    2, 0x08 /* Private */,
      28,    1,  195,    2, 0x08 /* Private */,
      29,    0,  198,    2, 0x08 /* Private */,
      30,    0,  199,    2, 0x08 /* Private */,
      31,    2,  200,    2, 0x08 /* Private */,
      34,    0,  205,    2, 0x08 /* Private */,
      35,    0,  206,    2, 0x08 /* Private */,
      36,    0,  207,    2, 0x08 /* Private */,
      37,    0,  208,    2, 0x08 /* Private */,
      38,    0,  209,    2, 0x08 /* Private */,
      39,    2,  210,    2, 0x08 /* Private */,
      42,    2,  215,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int,   14,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::Void, QMetaType::QPoint,   21,
    QMetaType::Void, 0x80000000 | 25,   18,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   32,   33,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   40,   41,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   40,   41,

       0        // eod
};

void ShaderViewer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ShaderViewer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_findReplace_clicked(); break;
        case 1: _t->on_refresh_clicked(); break;
        case 2: _t->on_unrefresh_clicked(); break;
        case 3: _t->on_resetEdits_clicked(); break;
        case 4: _t->on_intView_clicked(); break;
        case 5: _t->on_floatView_clicked(); break;
        case 6: _t->on_debugToggle_clicked(); break;
        case 7: _t->on_toggleLog_clicked(); break;
        case 8: _t->on_resources_sortByStep_clicked(); break;
        case 9: _t->on_resources_sortByResource_clicked(); break;
        case 10: _t->on_watch_itemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->readonly_keyPressed((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 12: _t->editable_keyPressed((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 13: _t->debug_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 14: _t->variables_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 15: _t->accessedResources_contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 16: _t->disassembly_buttonReleased((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 17: _t->disassemble_typeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->watch_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 19: _t->performFind(); break;
        case 20: _t->performFindAll(); break;
        case 21: _t->resultsDoubleClick((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 22: _t->performReplace(); break;
        case 23: _t->performReplaceAll(); break;
        case 24: _t->snippet_constants(); break;
        case 25: _t->snippet_samplers(); break;
        case 26: _t->snippet_resources(); break;
        case 27: _t->disasm_tooltipShow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 28: _t->disasm_tooltipHide((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ShaderViewer::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_ShaderViewer.data,
    qt_meta_data_ShaderViewer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ShaderViewer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShaderViewer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ShaderViewer.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IShaderViewer"))
        return static_cast< IShaderViewer*>(this);
    if (!strcmp(_clname, "ICaptureViewer"))
        return static_cast< ICaptureViewer*>(this);
    return QFrame::qt_metacast(_clname);
}

int ShaderViewer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
