/****************************************************************************
** Meta object code from reading C++ file 'RemoteManager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/RemoteManager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RemoteManager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RemoteManager_t {
    QByteArrayData data[19];
    char stringdata0[315];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RemoteManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RemoteManager_t qt_meta_stringdata_RemoteManager = {
    {
QT_MOC_LITERAL(0, 0, 13), // "RemoteManager"
QT_MOC_LITERAL(1, 14, 29), // "on_hosts_itemSelectionChanged"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 22), // "on_hosts_itemActivated"
QT_MOC_LITERAL(4, 68, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(5, 86, 4), // "item"
QT_MOC_LITERAL(6, 91, 6), // "column"
QT_MOC_LITERAL(7, 98, 22), // "on_hostname_textEdited"
QT_MOC_LITERAL(8, 121, 4), // "text"
QT_MOC_LITERAL(9, 126, 17), // "on_hosts_keyPress"
QT_MOC_LITERAL(10, 144, 10), // "QKeyEvent*"
QT_MOC_LITERAL(11, 155, 5), // "event"
QT_MOC_LITERAL(12, 161, 20), // "on_hostname_keyPress"
QT_MOC_LITERAL(13, 182, 22), // "on_runCommand_keyPress"
QT_MOC_LITERAL(14, 205, 21), // "on_refreshOne_clicked"
QT_MOC_LITERAL(15, 227, 24), // "on_addUpdateHost_clicked"
QT_MOC_LITERAL(16, 252, 21), // "on_refreshAll_clicked"
QT_MOC_LITERAL(17, 274, 18), // "on_connect_clicked"
QT_MOC_LITERAL(18, 293, 21) // "on_deleteHost_clicked"

    },
    "RemoteManager\0on_hosts_itemSelectionChanged\0"
    "\0on_hosts_itemActivated\0RDTreeWidgetItem*\0"
    "item\0column\0on_hostname_textEdited\0"
    "text\0on_hosts_keyPress\0QKeyEvent*\0"
    "event\0on_hostname_keyPress\0"
    "on_runCommand_keyPress\0on_refreshOne_clicked\0"
    "on_addUpdateHost_clicked\0on_refreshAll_clicked\0"
    "on_connect_clicked\0on_deleteHost_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RemoteManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x08 /* Private */,
       3,    2,   70,    2, 0x08 /* Private */,
       7,    1,   75,    2, 0x08 /* Private */,
       9,    1,   78,    2, 0x08 /* Private */,
      12,    1,   81,    2, 0x08 /* Private */,
      13,    1,   84,    2, 0x08 /* Private */,
      14,    0,   87,    2, 0x08 /* Private */,
      15,    0,   88,    2, 0x08 /* Private */,
      16,    0,   89,    2, 0x08 /* Private */,
      17,    0,   90,    2, 0x08 /* Private */,
      18,    0,   91,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void RemoteManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RemoteManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_hosts_itemSelectionChanged(); break;
        case 1: _t->on_hosts_itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->on_hostname_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->on_hosts_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 4: _t->on_hostname_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 5: _t->on_runCommand_keyPress((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 6: _t->on_refreshOne_clicked(); break;
        case 7: _t->on_addUpdateHost_clicked(); break;
        case 8: _t->on_refreshAll_clicked(); break;
        case 9: _t->on_connect_clicked(); break;
        case 10: _t->on_deleteHost_clicked(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject RemoteManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_RemoteManager.data,
    qt_meta_data_RemoteManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RemoteManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoteManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RemoteManager.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int RemoteManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
