/****************************************************************************
** Meta object code from reading C++ file 'TextureSaveDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Windows/Dialogs/TextureSaveDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TextureSaveDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TextureSaveDialog_t {
    QByteArrayData data[30];
    char stringdata0[693];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TextureSaveDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TextureSaveDialog_t qt_meta_stringdata_TextureSaveDialog = {
    {
QT_MOC_LITERAL(0, 0, 17), // "TextureSaveDialog"
QT_MOC_LITERAL(1, 18, 18), // "on_mainTex_clicked"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 21), // "on_overlayTex_clicked"
QT_MOC_LITERAL(4, 60, 33), // "on_fileFormat_currentIndexCha..."
QT_MOC_LITERAL(5, 94, 5), // "index"
QT_MOC_LITERAL(6, 100, 31), // "on_jpegCompression_valueChanged"
QT_MOC_LITERAL(7, 132, 4), // "arg1"
QT_MOC_LITERAL(8, 137, 24), // "on_exportAllMips_toggled"
QT_MOC_LITERAL(9, 162, 7), // "checked"
QT_MOC_LITERAL(10, 170, 17), // "on_oneMip_toggled"
QT_MOC_LITERAL(11, 188, 32), // "on_mipSelect_currentIndexChanged"
QT_MOC_LITERAL(12, 221, 25), // "on_mapSampleArray_toggled"
QT_MOC_LITERAL(13, 247, 25), // "on_resolveSamples_toggled"
QT_MOC_LITERAL(14, 273, 20), // "on_oneSample_toggled"
QT_MOC_LITERAL(15, 294, 35), // "on_sampleSelect_currentIndexC..."
QT_MOC_LITERAL(16, 330, 26), // "on_exportAllSlices_toggled"
QT_MOC_LITERAL(17, 357, 19), // "on_oneSlice_toggled"
QT_MOC_LITERAL(18, 377, 26), // "on_mapSlicesToGrid_toggled"
QT_MOC_LITERAL(19, 404, 24), // "on_cubeCruciform_toggled"
QT_MOC_LITERAL(20, 429, 34), // "on_sliceSelect_currentIndexCh..."
QT_MOC_LITERAL(21, 464, 25), // "on_gridWidth_valueChanged"
QT_MOC_LITERAL(22, 490, 19), // "on_alphaCol_clicked"
QT_MOC_LITERAL(23, 510, 31), // "on_alphaMap_currentIndexChanged"
QT_MOC_LITERAL(24, 542, 24), // "on_blackPoint_textEdited"
QT_MOC_LITERAL(25, 567, 24), // "on_whitePoint_textEdited"
QT_MOC_LITERAL(26, 592, 17), // "on_browse_clicked"
QT_MOC_LITERAL(27, 610, 22), // "on_filename_textEdited"
QT_MOC_LITERAL(28, 633, 29), // "on_saveCancelButtons_accepted"
QT_MOC_LITERAL(29, 663, 29) // "on_saveCancelButtons_rejected"

    },
    "TextureSaveDialog\0on_mainTex_clicked\0"
    "\0on_overlayTex_clicked\0"
    "on_fileFormat_currentIndexChanged\0"
    "index\0on_jpegCompression_valueChanged\0"
    "arg1\0on_exportAllMips_toggled\0checked\0"
    "on_oneMip_toggled\0on_mipSelect_currentIndexChanged\0"
    "on_mapSampleArray_toggled\0"
    "on_resolveSamples_toggled\0"
    "on_oneSample_toggled\0"
    "on_sampleSelect_currentIndexChanged\0"
    "on_exportAllSlices_toggled\0"
    "on_oneSlice_toggled\0on_mapSlicesToGrid_toggled\0"
    "on_cubeCruciform_toggled\0"
    "on_sliceSelect_currentIndexChanged\0"
    "on_gridWidth_valueChanged\0on_alphaCol_clicked\0"
    "on_alphaMap_currentIndexChanged\0"
    "on_blackPoint_textEdited\0"
    "on_whitePoint_textEdited\0on_browse_clicked\0"
    "on_filename_textEdited\0"
    "on_saveCancelButtons_accepted\0"
    "on_saveCancelButtons_rejected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TextureSaveDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x08 /* Private */,
       3,    0,  140,    2, 0x08 /* Private */,
       4,    1,  141,    2, 0x08 /* Private */,
       6,    1,  144,    2, 0x08 /* Private */,
       8,    1,  147,    2, 0x08 /* Private */,
      10,    1,  150,    2, 0x08 /* Private */,
      11,    1,  153,    2, 0x08 /* Private */,
      12,    1,  156,    2, 0x08 /* Private */,
      13,    1,  159,    2, 0x08 /* Private */,
      14,    1,  162,    2, 0x08 /* Private */,
      15,    1,  165,    2, 0x08 /* Private */,
      16,    1,  168,    2, 0x08 /* Private */,
      17,    1,  171,    2, 0x08 /* Private */,
      18,    1,  174,    2, 0x08 /* Private */,
      19,    1,  177,    2, 0x08 /* Private */,
      20,    1,  180,    2, 0x08 /* Private */,
      21,    1,  183,    2, 0x08 /* Private */,
      22,    0,  186,    2, 0x08 /* Private */,
      23,    1,  187,    2, 0x08 /* Private */,
      24,    1,  190,    2, 0x08 /* Private */,
      25,    1,  193,    2, 0x08 /* Private */,
      26,    0,  196,    2, 0x08 /* Private */,
      27,    1,  197,    2, 0x08 /* Private */,
      28,    0,  200,    2, 0x08 /* Private */,
      29,    0,  201,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TextureSaveDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TextureSaveDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_mainTex_clicked(); break;
        case 1: _t->on_overlayTex_clicked(); break;
        case 2: _t->on_fileFormat_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_jpegCompression_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 4: _t->on_exportAllMips_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->on_oneMip_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->on_mipSelect_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_mapSampleArray_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->on_resolveSamples_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->on_oneSample_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->on_sampleSelect_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->on_exportAllSlices_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->on_oneSlice_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->on_mapSlicesToGrid_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->on_cubeCruciform_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->on_sliceSelect_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->on_gridWidth_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 17: _t->on_alphaCol_clicked(); break;
        case 18: _t->on_alphaMap_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->on_blackPoint_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->on_whitePoint_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->on_browse_clicked(); break;
        case 22: _t->on_filename_textEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->on_saveCancelButtons_accepted(); break;
        case 24: _t->on_saveCancelButtons_rejected(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject TextureSaveDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_TextureSaveDialog.data,
    qt_meta_data_TextureSaveDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *TextureSaveDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextureSaveDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TextureSaveDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int TextureSaveDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
