/****************************************************************************
** Meta object code from reading C++ file 'RDTreeWidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../qrenderdoc/Widgets/Extended/RDTreeWidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RDTreeWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RDTreeWidget_t {
    QByteArrayData data[17];
    char stringdata0[199];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RDTreeWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RDTreeWidget_t qt_meta_stringdata_RDTreeWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "RDTreeWidget"
QT_MOC_LITERAL(1, 13, 9), // "mouseMove"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 12), // "QMouseEvent*"
QT_MOC_LITERAL(4, 37, 1), // "e"
QT_MOC_LITERAL(5, 39, 11), // "itemClicked"
QT_MOC_LITERAL(6, 51, 17), // "RDTreeWidgetItem*"
QT_MOC_LITERAL(7, 69, 4), // "item"
QT_MOC_LITERAL(8, 74, 6), // "column"
QT_MOC_LITERAL(9, 81, 11), // "itemChanged"
QT_MOC_LITERAL(10, 93, 17), // "itemDoubleClicked"
QT_MOC_LITERAL(11, 111, 13), // "itemActivated"
QT_MOC_LITERAL(12, 125, 18), // "currentItemChanged"
QT_MOC_LITERAL(13, 144, 7), // "current"
QT_MOC_LITERAL(14, 152, 8), // "previous"
QT_MOC_LITERAL(15, 161, 16), // "hoverItemChanged"
QT_MOC_LITERAL(16, 178, 20) // "itemSelectionChanged"

    },
    "RDTreeWidget\0mouseMove\0\0QMouseEvent*\0"
    "e\0itemClicked\0RDTreeWidgetItem*\0item\0"
    "column\0itemChanged\0itemDoubleClicked\0"
    "itemActivated\0currentItemChanged\0"
    "current\0previous\0hoverItemChanged\0"
    "itemSelectionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RDTreeWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       5,    2,   57,    2, 0x06 /* Public */,
       9,    2,   62,    2, 0x06 /* Public */,
      10,    2,   67,    2, 0x06 /* Public */,
      11,    2,   72,    2, 0x06 /* Public */,
      12,    2,   77,    2, 0x06 /* Public */,
      15,    1,   82,    2, 0x06 /* Public */,
      16,    0,   85,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 6,   13,   14,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,

       0        // eod
};

void RDTreeWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RDTreeWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->mouseMove((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 1: _t->itemClicked((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->itemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->itemDoubleClicked((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->itemActivated((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->currentItemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[2]))); break;
        case 6: _t->hoverItemChanged((*reinterpret_cast< RDTreeWidgetItem*(*)>(_a[1]))); break;
        case 7: _t->itemSelectionChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RDTreeWidget::*)(QMouseEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::mouseMove)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::itemClicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::itemChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::itemDoubleClicked)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::itemActivated)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * , RDTreeWidgetItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::currentItemChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)(RDTreeWidgetItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::hoverItemChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (RDTreeWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RDTreeWidget::itemSelectionChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject RDTreeWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<RDTreeView::staticMetaObject>(),
    qt_meta_stringdata_RDTreeWidget.data,
    qt_meta_data_RDTreeWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RDTreeWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RDTreeWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RDTreeWidget.stringdata0))
        return static_cast<void*>(this);
    return RDTreeView::qt_metacast(_clname);
}

int RDTreeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = RDTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void RDTreeWidget::mouseMove(QMouseEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void RDTreeWidget::itemClicked(RDTreeWidgetItem * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void RDTreeWidget::itemChanged(RDTreeWidgetItem * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void RDTreeWidget::itemDoubleClicked(RDTreeWidgetItem * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void RDTreeWidget::itemActivated(RDTreeWidgetItem * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void RDTreeWidget::currentItemChanged(RDTreeWidgetItem * _t1, RDTreeWidgetItem * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void RDTreeWidget::hoverItemChanged(RDTreeWidgetItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void RDTreeWidget::itemSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
